@@ -19,32 +19,35 @@
  */
 
 #include "akonadiresourcecreator.h"
+
 #include "autoqpointer.h"
 #include "collectionmodel.h"
+#include "resources/resources.h"
+#include "resources/akonadiresource.h"
 #include "kalarmsettings.h"
 #include "kalarmdirsettings.h"
+#include "kalarm_debug.h"
 
 #include <AkonadiCore/agentfilterproxymodel.h>
 #include <AkonadiCore/agentinstancecreatejob.h>
 #include <AkonadiCore/agentmanager.h>
-#include <kdbusconnectionpool.h>
 #include <AkonadiWidgets/agenttypedialog.h>
 #include <AkonadiWidgets/AgentConfigurationDialog>
 
-#include <kmessagebox.h>
+#include <KDBusConnectionPool>
+#include <KMessageBox>
 #include <KLocalizedString>
 
 #include <QTimer>
-#include "kalarm_debug.h"
 
 using namespace Akonadi;
 using namespace KAlarmCal;
 
 
 AkonadiResourceCreator::AkonadiResourceCreator(CalEvent::Type defaultType, QWidget* parent)
-    : QObject(),
-      mParent(parent),
-      mDefaultType(defaultType)
+    : QObject()
+    , mParent(parent)
+    , mDefaultType(defaultType)
 {
 }
 
@@ -76,25 +79,26 @@ void AkonadiResourceCreator::getAgentType()
             mimeType = KAlarmCal::MIME_TEMPLATE;
             break;
         default:
-            Q_EMIT finished(this, false);
+            deleteLater();   // error result
             return;
     }
     dlg->agentFilterProxyModel()->addMimeTypeFilter(mimeType);
     dlg->agentFilterProxyModel()->addCapabilityFilter(QStringLiteral("Resource"));
-    if (dlg->exec() != QDialog::Accepted)
+    if (dlg->exec() == QDialog::Accepted)
     {
-        Q_EMIT finished(this, false);
-        return;
+        mAgentType = dlg->agentType();
+        if (mAgentType.isValid())
+        {
+            connect(Resources::instance(), &Resources::resourceAdded,
+                                     this, &AkonadiResourceCreator::slotResourceAdded);
+
+            AgentInstanceCreateJob* job = new AgentInstanceCreateJob(mAgentType, mParent);
+            connect(job, &AgentInstanceCreateJob::result, this, &AkonadiResourceCreator::agentInstanceCreated);
+            job->start();
+            return;
+        }
     }
-    mAgentType = dlg->agentType();
-    if (!mAgentType.isValid())
-    {
-        Q_EMIT finished(this, false);
-        return;
-    }
-    AgentInstanceCreateJob* job = new AgentInstanceCreateJob(mAgentType, mParent);
-    connect(job, &AgentInstanceCreateJob::result, this, &AkonadiResourceCreator::agentInstanceCreated);
-    job->start();
+    deleteLater();   // error result
 }
 
 /******************************************************************************
@@ -108,7 +112,7 @@ void AkonadiResourceCreator::agentInstanceCreated(KJob* j)
     {
         qCCritical(KALARM_LOG) << "AkonadiResourceCreator::agentInstanceCreated: Failed to create new calendar resource:" << j->errorString();
         KMessageBox::error(nullptr, xi18nc("@info", "%1<nl/>(%2)", i18nc("@info", "Failed to create new calendar resource"), j->errorString()));
-        Q_EMIT finished(this, false);
+        deleteLater();   // error result
         return;
     }
 
@@ -148,7 +152,7 @@ void AkonadiResourceCreator::agentInstanceCreated(KJob* j)
                     if (url.isLocalFile())
                         path = url.path();
                     KMessageBox::sorry(nullptr, xi18nc("@info", "<para>The file or directory is already used by an existing resource:</para><para><filename>%1</filename></para>", path));
-                    Q_EMIT finished(this, false);
+                    deleteLater();   // error result
                     return;
                 }
             }
@@ -159,8 +163,29 @@ void AkonadiResourceCreator::agentInstanceCreated(KJob* j)
         // User has clicked cancel in the resource configuration dialog, or
         // other error, so remove the newly created agent instance.
         AgentManager::self()->removeInstance(mAgentInstance);
+        deleteLater();   // error result
+        return;
     }
-    Q_EMIT finished(this, result);
+
+    // AkonadiModel will notify when it has added the resource, which will
+    // call slotResourceAdded().
+}
+
+/******************************************************************************
+* Called when a collection is added to the AkonadiModel.
+* If it's the resource which has just been created, notify the fact.
+*/
+void AkonadiResourceCreator::slotResourceAdded(Resource& resource)
+{
+    if (resource.isValid()  &&  resource.is<AkonadiResource>())
+    {
+        AgentInstance agent = AgentManager::self()->instance(resource.configName());
+        if (agent == mAgentInstance)
+            Q_EMIT resourceAdded(resource, mDefaultType);
+    }
+
+    // This object has done its job, so delete it.
+    deleteLater();
 }
 
 /******************************************************************************
