@@ -18,9 +18,9 @@
  *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
-#include "kalarm.h"
 #include "alarmcalendar.h"
 
+#include "kalarm.h"
 #include "collectionmodel.h"
 #include "filedialog.h"
 #include "functions.h"
@@ -28,6 +28,8 @@
 #include "mainwindow.h"
 #include "messagebox.h"
 #include "preferences.h"
+#include "resources/resources.h"
+#include "kalarm_debug.h"
 
 #include <KCalendarCore/MemoryCalendar>
 #include <KCalendarCore/ICalFormat>
@@ -42,7 +44,6 @@
 #include <QTemporaryFile>
 #include <QStandardPaths>
 #include <QFileDialog>
-#include "kalarm_debug.h"
 
 using namespace Akonadi;
 using namespace KCalendarCore;
@@ -51,7 +52,7 @@ using namespace KAlarmCal;
 static KACalendar::Compat fix(const KCalendarCore::FileStorage::Ptr&);
 
 static const QString displayCalendarName = QStringLiteral("displaying.ics");
-static const Collection::Id DISPLAY_COL_ID = -1;   // collection ID used for displaying calendar
+static const Collection::Id DISPLAY_COL_ID = -1;   // resource ID used for displaying calendar
 
 AlarmCalendar* AlarmCalendar::mResourcesCalendar = nullptr;
 AlarmCalendar* AlarmCalendar::mDisplayCalendar = nullptr;
@@ -119,32 +120,22 @@ KAEvent* AlarmCalendar::getEvent(const EventId& eventId)
 * Constructor for the resources calendar.
 */
 AlarmCalendar::AlarmCalendar()
-    :
-      mCalType(RESOURCES),
-      mEventType(CalEvent::EMPTY),
-      mOpen(false),
-      mUpdateCount(0),
-      mUpdateSave(false),
-      mHaveDisabledAlarms(false)
+    : mCalType(RESOURCES)
+    , mEventType(CalEvent::EMPTY)
 {
-    AkonadiModel* model = AkonadiModel::instance();
-    connect(model, &AkonadiModel::eventsAdded, this, &AlarmCalendar::slotEventsAdded);
-    connect(model, &AkonadiModel::eventsToBeRemoved, this, &AlarmCalendar::slotEventsToBeRemoved);
-    connect(model, &AkonadiModel::eventChanged, this, &AlarmCalendar::slotEventChanged);
-    connect(model, &AkonadiModel::collectionStatusChanged, this, &AlarmCalendar::slotCollectionStatusChanged);
-    connect(model, &AkonadiModel::collectionsPopulated, this, &AlarmCalendar::slotCollectionsPopulated);
+    Resources* resources = Resources::instance();
+    connect(resources, &Resources::eventsAdded, this, &AlarmCalendar::slotEventsAdded);
+    connect(resources, &Resources::eventsToBeRemoved, this, &AlarmCalendar::slotEventsToBeRemoved);
+    connect(resources, &Resources::eventUpdated, this, &AlarmCalendar::slotEventUpdated);
+    connect(resources, &Resources::resourcesPopulated, this, &AlarmCalendar::slotResourcesPopulated);
+    connect(resources, &Resources::settingsChanged, this, &AlarmCalendar::slotResourceSettingsChanged);
 }
 
 /******************************************************************************
 * Constructor for a calendar file.
 */
 AlarmCalendar::AlarmCalendar(const QString& path, CalEvent::Type type)
-    :
-      mEventType(type),
-      mOpen(false),
-      mUpdateCount(0),
-      mUpdateSave(false),
-      mHaveDisabledAlarms(false)
+    : mEventType(type)
 {
     switch (type)
     {
@@ -248,7 +239,8 @@ int AlarmCalendar::load()
 
         QString filename;
         qCDebug(KALARM_LOG) << "AlarmCalendar::load:" << mUrl.toDisplayString();
-        if (!mUrl.isLocalFile()) {
+        if (!mUrl.isLocalFile())
+        {
             auto getJob = KIO::storedGet(mUrl);
             KJobWidgets::setWindow(getJob, MainWindow::mainMainWindow());
             if (!getJob->exec())
@@ -263,15 +255,16 @@ int AlarmCalendar::load()
             tmpFile.write(getJob->data());
             qCDebug(KALARM_LOG) << "--- Downloaded to" << tmpFile.fileName();
             filename = tmpFile.fileName();
-        } else {
-            filename = mUrl.toLocalFile();
         }
+        else
+            filename = mUrl.toLocalFile();
         mCalendarStorage->calendar()->setTimeZone(Preferences::timeSpecAsZone());
         mCalendarStorage->setFileName(filename);
         if (!mCalendarStorage->load())
         {
             // Check if the file is zero length
-            if (mUrl.isLocalFile()) {
+            if (mUrl.isLocalFile())
+            {
                 auto statJob = KIO::stat(KIO::upUrl(mUrl));
                 KJobWidgets::setWindow(statJob, MainWindow::mainMainWindow());
                 statJob->exec();
@@ -291,9 +284,10 @@ int AlarmCalendar::load()
             return -1;
         }
         if (!mLocalFile.isEmpty())
-            if (mLocalFile.startsWith(QDir::tempPath())) {
+        {
+            if (mLocalFile.startsWith(QDir::tempPath()))
                 QFile::remove(mLocalFile);
-            }
+        }
         mLocalFile = filename;
         fix(mCalendarStorage);   // convert events to current KAlarm format for when calendar is saved
         updateDisplayKAEvents();
@@ -383,9 +377,8 @@ void AlarmCalendar::close()
     {
         if (!mLocalFile.isEmpty())
         {
-            if (mLocalFile.startsWith(QDir::tempPath())) { // removes it only if it IS a temporary file
+            if (mLocalFile.startsWith(QDir::tempPath())) // removes it only if it IS a temporary file
                 QFile::remove(mLocalFile);
-            }
             mLocalFile = QStringLiteral("");
         }
     }
@@ -403,6 +396,11 @@ void AlarmCalendar::close()
         removeKAEvents(mResourceMap.begin().key(), true, CalEvent::ACTIVE | CalEvent::ARCHIVED | CalEvent::TEMPLATE | CalEvent::DISPLAYING);
 }
 
+/******************************************************************************
+* Create a KAEvent instance corresponding to each KCalendarCore::Event in the
+* display calendar, and store them in the event map in place of the old set.
+* Called after the display calendar has completed loading.
+*/
 void AlarmCalendar::updateDisplayKAEvents()
 {
     if (mCalType == RESOURCES)
@@ -410,10 +408,8 @@ void AlarmCalendar::updateDisplayKAEvents()
     qCDebug(KALARM_LOG) << "AlarmCalendar::updateDisplayKAEvents";
     const Collection::Id key = DISPLAY_COL_ID;
     KAEvent::List& events = mResourceMap[key];
-    int i, end;
-    for (i = 0, end = events.count();  i < end;  ++i)
+    for (KAEvent* event : events)
     {
-        KAEvent* event = events[i];
         mEventMap.remove(EventId(key, event->id()));
         delete event;
     }
@@ -423,10 +419,9 @@ void AlarmCalendar::updateDisplayKAEvents()
     if (!cal)
         return;
 
-    Event::List kcalevents = cal->rawEvents();
-    for (i = 0, end = kcalevents.count();  i < end;  ++i)
+    const Event::List kcalevents = cal->rawEvents();
+    for (Event::Ptr kcalevent : kcalevents)
     {
-        Event::Ptr kcalevent = kcalevents[i];
         if (kcalevent->alarms().isEmpty())
             continue;    // ignore events without alarms
 
@@ -465,7 +460,7 @@ void AlarmCalendar::removeKAEvents(Collection::Id key, bool closing, CalEvent::T
             if (remove)
             {
                 if (key != DISPLAY_COL_ID)
-                    qCCritical(KALARM_LOG) << "AlarmCalendar::removeKAEvents: Event" << event->id() << ", collection" << event->collectionId() << "Indexed under collection" << key;
+                    qCCritical(KALARM_LOG) << "AlarmCalendar::removeKAEvents: Event" << event->id() << ", resource" << event->collectionId() << "Indexed under resource" << key;
             }
             else
                 remove = event->category() & types;
@@ -497,25 +492,33 @@ void AlarmCalendar::removeKAEvents(Collection::Id key, bool closing, CalEvent::T
 }
 
 /******************************************************************************
-* Called when the enabled or read-only status of a collection has changed.
-* If the collection is now disabled, remove its events from the calendar.
+* Called when the enabled or read-only status of a resource has changed.
+* If the resource is now disabled, remove its events from the calendar.
 */
-void AlarmCalendar::slotCollectionStatusChanged(const Collection& collection, AkonadiModel::Change change, const QVariant& value, bool inserted)
+void AlarmCalendar::slotResourceSettingsChanged(Resource& resource, ResourceType::Changes change)
 {
-    if (!inserted  &&  change == AkonadiModel::Enabled)
+    if (change & ResourceType::Enabled)
     {
-        // For each alarm type which has been disabled, remove the collection's
-        // events from the map, but not from AkonadiModel.
-        CalEvent::Types enabled = static_cast<CalEvent::Types>(value.toInt());
-        CalEvent::Types disabled = ~enabled & (CalEvent::ACTIVE | CalEvent::ARCHIVED | CalEvent::TEMPLATE);
-        removeKAEvents(collection.id(), false, disabled);
+        if (resource.isValid())
+        {
+            // For each alarm type which has been disabled, remove the
+            // collection's events from the map, but not from the resource.
+            const CalEvent::Types enabled = resource.enabledTypes();
+            const CalEvent::Types disabled = ~enabled & (CalEvent::ACTIVE | CalEvent::ARCHIVED | CalEvent::TEMPLATE);
+            removeKAEvents(resource.id(), false, disabled);
+
+            // For each alarm type which has been enabled, add the collection's
+            // events to the map.
+            if (enabled != CalEvent::EMPTY)
+                slotEventsAdded(resource, resource.events());
+        }
     }
 }
 
 /******************************************************************************
-* Called when all collections have been populated for the first time.
+* Called when all resources have been populated for the first time.
 */
-void AlarmCalendar::slotCollectionsPopulated()
+void AlarmCalendar::slotResourcesPopulated()
 {
     // Now that all calendars have been processed, all repeat-at-login alarms
     // will have been triggered. Prevent any new or updated repeat-at-login
@@ -524,39 +527,35 @@ void AlarmCalendar::slotCollectionsPopulated()
 }
 
 /******************************************************************************
-* Called when events have been added to AkonadiModel.
+* Called when events have been added to a resource.
 * Add corresponding KAEvent instances to those held by AlarmCalendar.
+* All events must have their resource ID set.
 */
-void AlarmCalendar::slotEventsAdded(const AkonadiModel::EventList& events)
+void AlarmCalendar::slotEventsAdded(Resource& resource, const QList<KAEvent>& events)
 {
-    for (int i = 0, count = events.count();  i < count;  ++i)
-        slotEventChanged(events[i]);
+    for (const KAEvent& event : events)
+        slotEventUpdated(resource, event);
 }
 
 /******************************************************************************
-* Called when an event has been changed in AkonadiModel.
+* Called when an event has been changed in a resource.
 * Change the corresponding KAEvent instance held by AlarmCalendar.
+* The event must have its resource ID set.
 */
-void AlarmCalendar::slotEventChanged(const AkonadiModel::Event& event)
+void AlarmCalendar::slotEventUpdated(Resource& resource, const KAEvent& event)
 {
-    if (!event.isConsistent())
-    {
-        qCCritical(KALARM_LOG) << "AlarmCalendar::slotEventChanged: Inconsistent AkonadiModel::Event: event:" << event.event.collectionId() << ", collection" << event.collection.id();
-        return;
-    }
-
     bool added = true;
     bool updated = false;
-    KAEventMap::Iterator it = mEventMap.find(event.eventId());
+    KAEventMap::Iterator it = mEventMap.find(EventId(event));
     if (it != mEventMap.end())
     {
         // The event ID already exists - remove the existing event first
         KAEvent* storedEvent = it.value();
-        if (event.event.category() == storedEvent->category())
+        if (event.category() == storedEvent->category())
         {
             // The existing event is the same type - update it in place
-            *storedEvent = event.event;
-            addNewEvent(event.collection, storedEvent, true);
+            *storedEvent = event;
+            addNewEvent(resource, storedEvent, true);
             updated = true;
         }
         else
@@ -564,29 +563,27 @@ void AlarmCalendar::slotEventChanged(const AkonadiModel::Event& event)
         added = false;
     }
     if (!updated)
-        addNewEvent(event.collection, new KAEvent(event.event));
+        addNewEvent(resource, new KAEvent(event));
 
-    if (event.event.category() == CalEvent::ACTIVE)
+    if (event.category() == CalEvent::ACTIVE)
     {
-        bool enabled = event.event.enabled();
+        bool enabled = event.enabled();
         checkForDisabledAlarms(!enabled, enabled);
-        if (!mIgnoreAtLogin  &&  added  &&  enabled  &&  event.event.repeatAtLogin())
-            Q_EMIT atLoginEventAdded(event.event);
+        if (!mIgnoreAtLogin  &&  added  &&  enabled  &&  event.repeatAtLogin())
+            Q_EMIT atLoginEventAdded(event);
     }
 }
 
 /******************************************************************************
-* Called when events are about to be removed from AkonadiModel.
+* Called when events are about to be removed from a resource.
 * Remove the corresponding KAEvent instances held by AlarmCalendar.
 */
-void AlarmCalendar::slotEventsToBeRemoved(const AkonadiModel::EventList& events)
+void AlarmCalendar::slotEventsToBeRemoved(Resource& resource, const QList<KAEvent>& events)
 {
-    for (int i = 0, count = events.count();  i < count;  ++i)
+    for (const KAEvent& event : events)
     {
-        if (!events[i].isConsistent())
-            qCCritical(KALARM_LOG) << "AlarmCalendar::slotEventsToBeRemoved: Inconsistent AkonadiModel::Event: event:" << events[i].event.collectionId() << ", collection" << events[i].collection.id();
-        else if (mEventMap.contains(events[i].eventId()))
-            deleteEventInternal(events[i].event, events[i].collection, false);
+        if (mEventMap.contains(EventId(event)))
+            deleteEventInternal(event, resource, false);
     }
 }
 
@@ -597,10 +594,12 @@ void AlarmCalendar::slotEventsToBeRemoved(const AkonadiModel::EventList& events)
 * Reply = true if all alarms in the calendar were successfully imported
 *       = false if any alarms failed to be imported.
 */
-bool AlarmCalendar::importAlarms(QWidget* parent, Collection* collection)
+bool AlarmCalendar::importAlarms(QWidget* parent, Resource* resourceptr)
 {
     if (mCalType != RESOURCES)
         return false;
+    Resource nullresource;
+    Resource& resource(resourceptr ? *resourceptr : nullresource);
     qCDebug(KALARM_LOG) << "AlarmCalendar::importAlarms";
     const QUrl url = QFileDialog::getOpenFileUrl(parent, QString(), mLastImportUrl,
                                                  QStringLiteral("%1 (*.vcs *.ics)").arg(i18nc("@info", "Calendar Files")));
@@ -659,13 +658,11 @@ bool AlarmCalendar::importAlarms(QWidget* parent, Collection* collection)
     }
     else
     {
-        KACalendar::Compat caltype = fix(calStorage);
-        CalEvent::Types wantedTypes = collection && collection->isValid() ? CalEvent::types(collection->contentMimeTypes()) : CalEvent::EMPTY;
-        Collection activeColl, archiveColl, templateColl;
-        Event::List events = cal->rawEvents();
-        for (int i = 0, end = events.count();  i < end;  ++i)
+        const KACalendar::Compat caltype = fix(calStorage);
+        const CalEvent::Types wantedTypes = resource.alarmTypes();
+        const Event::List events = cal->rawEvents();
+        for (Event::Ptr event : events)
         {
-            Event::Ptr event = events[i];
             if (event->alarms().isEmpty()  ||  !KAEvent(event).isValid())
                 continue;    // ignore events without alarms, or usable alarms
             CalEvent::Type type = CalEvent::status(event);
@@ -675,24 +672,25 @@ bool AlarmCalendar::importAlarms(QWidget* parent, Collection* collection)
                 if (caltype == KACalendar::Incompatible)
                     type = CalEvent::ACTIVE;
             }
-            Collection* coll;
-            if (collection  &&  collection->isValid())
+            Resource res;
+            if (resource.isValid())
             {
                 if (!(type & wantedTypes))
                     continue;
-                coll = collection;
+                res = resource;
             }
             else
             {
                 switch (type)
                 {
-                    case CalEvent::ACTIVE:    coll = &activeColl;  break;
-                    case CalEvent::ARCHIVED:  coll = &archiveColl;  break;
-                    case CalEvent::TEMPLATE:  coll = &templateColl;  break;
-                    default:  continue;
+                    case CalEvent::ACTIVE:
+                    case CalEvent::ARCHIVED:
+                    case CalEvent::TEMPLATE:
+                        break;
+                    default:
+                        continue;
                 }
-                if (!coll->isValid())
-                    *coll = CollectionControlModel::destination(type);
+                res = CollectionControlModel::destination(type);
             }
 
             Event::Ptr newev(new Event(*event));
@@ -702,9 +700,8 @@ bool AlarmCalendar::importAlarms(QWidget* parent, Collection* collection)
             if (type == CalEvent::ACTIVE  &&  !newev->summary().isEmpty())
             {
                 const Alarm::List& alarms = newev->alarms();
-                for (int ai = 0, aend = alarms.count();  ai < aend;  ++ai)
+                for (Alarm::Ptr alarm : alarms)
                 {
-                    Alarm::Ptr alarm = alarms[ai];
                     if (alarm->type() == Alarm::Display  &&  alarm->text().isEmpty())
                         alarm->setText(newev->summary());
                 }
@@ -713,8 +710,7 @@ bool AlarmCalendar::importAlarms(QWidget* parent, Collection* collection)
 
             // Give the event a new ID and add it to the calendars
             newev->setUid(CalEvent::uid(CalFormat::createUniqueId(), type));
-            KAEvent* newEvent = new KAEvent(newev);
-            if (!AkonadiModel::instance()->addEvent(*newEvent, *coll))
+            if (!res.addEvent(KAEvent(newev)))
                 success = false;
         }
 
@@ -740,7 +736,7 @@ bool AlarmCalendar::exportAlarms(const KAEvent::List& events, QWidget* parent)
                                                &append);
     if (file.isEmpty())
         return false;
-    QUrl url = QUrl::fromLocalFile(file);
+    const QUrl url = QUrl::fromLocalFile(file);
     if (!url.isValid())
     {
         qCDebug(KALARM_LOG) << "AlarmCalendar::exportAlarms: Invalid URL" << url;
@@ -774,8 +770,8 @@ bool AlarmCalendar::exportAlarms(const KAEvent::List& events, QWidget* parent)
     {
         const KAEvent* event = events[i];
         Event::Ptr kcalEvent(new Event);
-        CalEvent::Type type = event->category();
-        QString id = CalEvent::uid(kcalEvent->uid(), type);
+        const CalEvent::Type type = event->category();
+        const QString id = CalEvent::uid(kcalEvent->uid(), type);
         kcalEvent->setUid(id);
         event->updateKCalEvent(kcalEvent, KAEvent::UID_IGNORE);
         if (calendar->addEvent(kcalEvent))
@@ -872,9 +868,9 @@ bool AlarmCalendar::save()
 */
 void AlarmCalendar::purgeEvents(const KAEvent::List& events)
 {
-    for (int i = 0, end = events.count();  i < end;  ++i)
+    for (const KAEvent* event : events)
     {
-        deleteEventInternal(*events[i]);
+        deleteEventInternal(*event);
     }
     if (mHaveDisabledAlarms)
         checkForDisabledAlarms();
@@ -895,15 +891,17 @@ void AlarmCalendar::purgeEvents(const KAEvent::List& events)
 *              is updated.
 *       = false if an error occurred, in which case 'event' is unchanged.
 */
-bool AlarmCalendar::addEvent(KAEvent& evnt, QWidget* promptParent, bool useEventID, Collection* collection, bool noPrompt, bool* cancelled)
+bool AlarmCalendar::addEvent(KAEvent& evnt, QWidget* promptParent, bool useEventID, Resource* resourceptr, bool noPrompt, bool* cancelled)
 {
     if (cancelled)
         *cancelled = false;
     if (!mOpen)
         return false;
     // Check that the event type is valid for the calendar
-    qCDebug(KALARM_LOG) << "AlarmCalendar::addEvent:" << evnt.id();
-    CalEvent::Type type = evnt.category();
+    Resource nullresource;
+    Resource& resource(resourceptr ? *resourceptr : nullresource);
+    qCDebug(KALARM_LOG) << "AlarmCalendar::addEvent:" << evnt.id() << ", resource" << resource.id();
+    const CalEvent::Type type = evnt.category();
     if (type != mEventType)
     {
         switch (type)
@@ -920,7 +918,7 @@ bool AlarmCalendar::addEvent(KAEvent& evnt, QWidget* promptParent, bool useEvent
         }
     }
 
-    Collection::Id key = (collection && collection->isValid()) ? collection->id() : -1;
+    Collection::Id key = resource.id();
     Event::Ptr kcalEvent((mCalType == RESOURCES) ? (Event*)nullptr : new Event);
     KAEvent* event = new KAEvent(evnt);
     QString id = event->id();
@@ -946,23 +944,23 @@ bool AlarmCalendar::addEvent(KAEvent& evnt, QWidget* promptParent, bool useEvent
     bool remove = false;
     if (mCalType == RESOURCES)
     {
-        Collection col;
-        if (collection  &&  CollectionControlModel::isEnabled(*collection, type))
-            col = *collection;
+        Resource res;
+        if (resource.isEnabled(type))
+            res = resource;
         else
         {
-            col = CollectionControlModel::destination(type, promptParent, noPrompt, cancelled);
-            if (!col.isValid())
+            res = CollectionControlModel::destination(type, promptParent, noPrompt, cancelled);
+            if (!res.isValid())
             {
                 const char* typeStr = (type == CalEvent::ACTIVE) ? "Active alarm" : (type == CalEvent::ARCHIVED) ? "Archived alarm" : "alarm Template";
                 qCWarning(KALARM_LOG) << "AlarmCalendar::addEvent: Error! Cannot create" << typeStr << "(No default calendar is defined)";
             }
         }
-        if (col.isValid())
+        if (res.isValid())
         {
             // Don't add event to mEventMap yet - its Akonadi item id is not yet known.
             // It will be added once it is inserted into AkonadiModel.
-            ok = AkonadiModel::instance()->addEvent(*event, col);
+            ok = res.addEvent(*event);
             remove = ok;   // if success, delete the local event instance on exit
             if (ok  &&  type == CalEvent::ACTIVE  &&  !event->enabled())
                 checkForDisabledAlarms(true, false);
@@ -975,7 +973,7 @@ bool AlarmCalendar::addEvent(KAEvent& evnt, QWidget* promptParent, bool useEvent
         key = DISPLAY_COL_ID;
         if (!mEventMap.contains(EventId(key, event->id())))
         {
-            addNewEvent(Collection(), event);
+            addNewEvent(Resource(), event);
             ok = mCalendarStorage->calendar()->addEvent(kcalEvent);
             remove = !ok;
         }
@@ -1009,20 +1007,20 @@ bool AlarmCalendar::addEvent(KAEvent& evnt, QWidget* promptParent, bool useEvent
 * If 'replace' is true, an existing event is being updated (NOTE: its category()
 * must remain the same).
 */
-void AlarmCalendar::addNewEvent(const Collection& collection, KAEvent* event, bool replace)
+void AlarmCalendar::addNewEvent(const Resource& resource, KAEvent* event, bool replace)
 {
-    Collection::Id key = collection.isValid() ? collection.id() : -1;
+    const Collection::Id key = resource.id();
     event->setCollectionId(key);
     if (!replace)
     {
         mResourceMap[key] += event;
         mEventMap[EventId(key, event->id())] = event;
     }
-    if (collection.isValid()  &&  (AkonadiModel::types(collection) & CalEvent::ACTIVE)
+    if ((resource.alarmTypes() & CalEvent::ACTIVE)
     &&  event->category() == CalEvent::ACTIVE)
     {
         // Update the earliest alarm to trigger
-        KAEvent* earliest = mEarliestAlarm.value(key, (KAEvent*)nullptr);
+        const KAEvent* earliest = mEarliestAlarm.value(key, (KAEvent*)nullptr);
         if (replace  &&  earliest == event)
             findEarliestAlarm(key);
         else
@@ -1049,7 +1047,7 @@ void AlarmCalendar::addNewEvent(const Collection& collection, KAEvent* event, bo
 */
 bool AlarmCalendar::modifyEvent(const EventId& oldEventId, KAEvent& newEvent)
 {
-    EventId newId(oldEventId.collectionId(), newEvent.id());
+    const EventId newId(oldEventId.collectionId(), newEvent.id());
     qCDebug(KALARM_LOG) << "AlarmCalendar::modifyEvent:" << oldEventId << "->" << newId;
     bool noNewId = newId.isEmpty();
     if (!noNewId  &&  oldEventId == newId)
@@ -1063,7 +1061,7 @@ bool AlarmCalendar::modifyEvent(const EventId& oldEventId, KAEvent& newEvent)
     {
         // Set the event's ID and Akonadi ID, and update the old
         // event in Akonadi.
-        KAEvent* storedEvent = event(oldEventId);
+        const KAEvent* storedEvent = event(oldEventId);
         if (!storedEvent)
         {
             qCCritical(KALARM_LOG) << "AlarmCalendar::modifyEvent: Old event not found";
@@ -1071,15 +1069,15 @@ bool AlarmCalendar::modifyEvent(const EventId& oldEventId, KAEvent& newEvent)
         }
         if (noNewId)
             newEvent.setEventId(CalFormat::createUniqueId());
-        Collection c = AkonadiModel::instance()->collectionById(oldEventId.collectionId());
-        if (!c.isValid())
+        Resource resource = Resources::resource(oldEventId.collectionId());
+        if (!resource.isValid())
             return false;
         // Don't add new event to mEventMap yet - its Akonadi item id is not yet known
-        if (!AkonadiModel::instance()->addEvent(newEvent, c))
+        if (!resource.addEvent(newEvent))
             return false;
         // Note: deleteEventInternal() will delete storedEvent before using the
         // event parameter, so need to pass a copy as the parameter.
-        deleteEventInternal(KAEvent(*storedEvent), c);
+        deleteEventInternal(KAEvent(*storedEvent), resource);
         if (mHaveDisabledAlarms)
             checkForDisabledAlarms();
     }
@@ -1109,11 +1107,10 @@ KAEvent* AlarmCalendar::updateEvent(const KAEvent* evnt)
     KAEvent* kaevnt = event(EventId(*evnt));
     if (kaevnt)
     {
-        KAEvent newEvnt(*evnt);
-        newEvnt.setItemId(evnt->itemId());
-        if (AkonadiModel::instance()->updateEvent(newEvnt))
+        Resource resource = Resources::resourceForEvent(evnt->id());
+        if (resource.updateEvent(*evnt))
         {
-            *kaevnt = newEvnt;
+            *kaevnt = *evnt;
             return kaevnt;
         }
     }
@@ -1130,7 +1127,7 @@ bool AlarmCalendar::deleteEvent(const KAEvent& event, bool saveit)
 {
     if (mOpen  &&  mCalType == RESOURCES)
     {
-        CalEvent::Type status = deleteEventInternal(event);
+        const CalEvent::Type status = deleteEventInternal(event);
         if (mHaveDisabledAlarms)
             checkForDisabledAlarms();
         if (status != CalEvent::EMPTY)
@@ -1151,7 +1148,8 @@ bool AlarmCalendar::deleteDisplayEvent(const QString& eventID, bool saveit)
 {
     if (mOpen  &&  mCalType != RESOURCES)
     {
-        CalEvent::Type status = deleteEventInternal(eventID);
+        Resource resource;
+        const CalEvent::Type status = deleteEventInternal(eventID, KAEvent(), resource, false);
         if (mHaveDisabledAlarms)
             checkForDisabledAlarms();
         if (status != CalEvent::EMPTY)
@@ -1166,31 +1164,31 @@ bool AlarmCalendar::deleteDisplayEvent(const QString& eventID, bool saveit)
 
 /******************************************************************************
 * Internal method to delete the specified event from the calendar and lists.
-* Reply = event status, if it was found in the resource calendar/collection or
-*         local calendar
+* Reply = event status, if it was found in the resource calendar/calendar
+*         resource or local calendar
 *       = CalEvent::EMPTY otherwise.
 */
 CalEvent::Type AlarmCalendar::deleteEventInternal(const KAEvent& event, bool deleteFromAkonadi)
 {
-    Collection collection = AkonadiModel::instance()->collectionById(event.collectionId());
-    if (!collection.isValid())
+    Resource resource = Resources::resource(event.collectionId());
+    if (!resource.isValid())
         return CalEvent::EMPTY;
-    return deleteEventInternal(event.id(), event, collection, deleteFromAkonadi);
+    return deleteEventInternal(event.id(), event, resource, deleteFromAkonadi);
 }
 
-CalEvent::Type AlarmCalendar::deleteEventInternal(const KAEvent& event, const Akonadi::Collection& collection, bool deleteFromAkonadi)
+CalEvent::Type AlarmCalendar::deleteEventInternal(const KAEvent& event, Resource& resource, bool deleteFromAkonadi)
 {
-    if (!collection.isValid())
+    if (!resource.isValid())
         return CalEvent::EMPTY;
-    if (event.collectionId() != collection.id())
+    if (event.collectionId() != resource.id())
     {
-        qCCritical(KALARM_LOG) << "AlarmCalendar::deleteEventInternal: Event" << event.id() << ": collection" << event.collectionId() << "differs from 'collection'" << collection.id();
+        qCCritical(KALARM_LOG) << "AlarmCalendar::deleteEventInternal: Event" << event.id() << ": resource" << event.collectionId() << "differs from 'resource'" << resource.id();
         return CalEvent::EMPTY;
     }
-    return deleteEventInternal(event.id(), event, collection, deleteFromAkonadi);
+    return deleteEventInternal(event.id(), event, resource, deleteFromAkonadi);
 }
 
-CalEvent::Type AlarmCalendar::deleteEventInternal(const QString& eventID, const KAEvent& event, const Akonadi::Collection& collection, bool deleteFromAkonadi)
+CalEvent::Type AlarmCalendar::deleteEventInternal(const QString& eventID, const KAEvent& event, Resource& resource, bool deleteFromAkonadi)
 {
     // Make a copy of the KAEvent and the ID QString, since the supplied
     // references might be destructed when the event is deleted below.
@@ -1200,7 +1198,7 @@ CalEvent::Type AlarmCalendar::deleteEventInternal(const QString& eventID, const
     Event::Ptr kcalEvent;
     if (mCalendarStorage)
         kcalEvent = mCalendarStorage->calendar()->event(id);
-    Collection::Id key = collection.isValid() ? collection.id() : -1;
+    const Collection::Id key = resource.id();
     KAEventMap::Iterator it = mEventMap.find(EventId(key, id));
     if (it != mEventMap.end())
     {
@@ -1212,7 +1210,7 @@ CalEvent::Type AlarmCalendar::deleteEventInternal(const QString& eventID, const
             events.remove(i);
         delete ev;
         if (mEarliestAlarm[key] == ev)
-            findEarliestAlarm(collection);
+            findEarliestAlarm(resource);
     }
     else
     {
@@ -1236,7 +1234,7 @@ CalEvent::Type AlarmCalendar::deleteEventInternal(const QString& eventID, const
     {
         // It's an Akonadi event
         CalEvent::Type s = paramEvent.category();
-        if (AkonadiModel::instance()->deleteEvent(paramEvent))
+        if (resource.deleteEvent(paramEvent))
             status = s;
     }
     return status;
@@ -1245,7 +1243,7 @@ CalEvent::Type AlarmCalendar::deleteEventInternal(const QString& eventID, const
 
 /******************************************************************************
 * Return the event with the specified ID.
-* If 'checkDuplicates' is true, and the collection ID is invalid, if there is
+* If 'checkDuplicates' is true, and the resource ID is invalid, if there is
 * a unique event with the given ID, it will be returned.
 */
 KAEvent* AlarmCalendar::event(const EventId& uniqueID, bool checkDuplicates)
@@ -1255,9 +1253,9 @@ KAEvent* AlarmCalendar::event(const EventId& uniqueID, bool checkDuplicates)
     const QString eventId = uniqueID.eventId();
     if (uniqueID.collectionId() == -1  &&  checkDuplicates)
     {
-        // The collection isn't known, but use the event ID if it is
-        // unique among all collections.
-        KAEvent::List list = events(eventId);
+        // The resource isn't known, but use the event ID if it is unique among
+        // all resources.
+        const KAEvent::List list = events(eventId);
         if (list.count() > 1)
         {
             qCWarning(KALARM_LOG) << "AlarmCalendar::event: Multiple events found with ID" << eventId;
@@ -1293,11 +1291,11 @@ KAEvent* AlarmCalendar::templateEvent(const QString& templateName)
 {
     if (templateName.isEmpty())
         return nullptr;
-    KAEvent::List eventlist = events(CalEvent::TEMPLATE);
-    for (int i = 0, end = eventlist.count();  i < end;  ++i)
+    const KAEvent::List eventlist = events(CalEvent::TEMPLATE);
+    for (KAEvent* event : eventlist)
     {
-        if (eventlist[i]->templateName() == templateName)
-            return eventlist[i];
+        if (event->templateName() == templateName)
+            return event;
     }
     return nullptr;
 }
@@ -1325,23 +1323,23 @@ KAEvent::List AlarmCalendar::events(const QString& uniqueId) const
 * Return all events in the calendar which contain alarms.
 * Optionally the event type can be filtered, using an OR of event types.
 */
-KAEvent::List AlarmCalendar::events(const Akonadi::Collection& collection, CalEvent::Types type) const
+KAEvent::List AlarmCalendar::events(const Resource& resource, CalEvent::Types type) const
 {
     KAEvent::List list;
-    if (mCalType != RESOURCES  &&  (!mCalendarStorage || collection.isValid()))
+    if (mCalType != RESOURCES  &&  (!mCalendarStorage || resource.isValid()))
         return list;
-    if (collection.isValid())
+    if (resource.isValid())
     {
-        Collection::Id key = collection.isValid() ? collection.id() : -1;
+        const Collection::Id key = resource.id();
         ResourceMap::ConstIterator rit = mResourceMap.constFind(key);
         if (rit == mResourceMap.constEnd())
             return list;
         const KAEvent::List events = rit.value();
         if (type == CalEvent::EMPTY)
             return events;
-        for (int i = 0, end = events.count();  i < end;  ++i)
-            if (type & events[i]->category())
-                list += events[i];
+        for (KAEvent* const event : events)
+            if (type & event->category())
+                list += event;
     }
     else
     {
@@ -1352,9 +1350,9 @@ KAEvent::List AlarmCalendar::events(const Akonadi::Collection& collection, CalEv
                 list += events;
             else
             {
-                for (int i = 0, end = events.count();  i < end;  ++i)
-                    if (type & events[i]->category())
-                        list += events[i];
+                for (KAEvent* const event : events)
+                    if (type & event->category())
+                        list += event;
             }
         }
     }
@@ -1375,7 +1373,7 @@ Event::List AlarmCalendar::kcalEvents(CalEvent::Type type)
     list = mCalendarStorage->calendar()->rawEvents();
     for (int i = 0;  i < list.count();  )
     {
-        Event::Ptr event = list[i];
+        Event::Ptr event = list.at(i);
         if (event->alarms().isEmpty()
         ||  (type != CalEvent::EMPTY  &&  !(type & CalEvent::status(event)))
         ||  !KAEvent(event).isValid())
@@ -1391,27 +1389,15 @@ Event::List AlarmCalendar::kcalEvents(CalEvent::Type type)
 * Return whether an event is read-only.
 * Display calendar events are always returned as read-only.
 */
-bool AlarmCalendar::eventReadOnly(Item::Id id) const
+bool AlarmCalendar::eventReadOnly(const QString& eventId) const
 {
     if (mCalType != RESOURCES)
         return true;
-    AkonadiModel* model = AkonadiModel::instance();
-    Collection collection = model->collectionForItem(id);
-    KAEvent event = model->event(id);
-    if (CollectionControlModel::isWritableEnabled(collection, event.category()) <= 0)
-        return true;
-    return !event.isValid()  ||  event.isReadOnly();
-    //   ||  compatibility(event) != KACalendar::Current;
-}
-
-/******************************************************************************
-* Return the collection containing a specified event.
-*/
-Collection AlarmCalendar::collectionForEvent(Item::Id itemId) const
-{
-    if (mCalType != RESOURCES)
-        return Collection();
-    return AkonadiModel::instance()->collectionForItem(itemId);
+    KAEvent event;
+    const Resource resource = Resources::resourceForEvent(eventId, event);
+    return !event.isValid()  ||  event.isReadOnly()
+       ||  !resource.isWritable(event.category());
+//TODO   ||  compatibility(event) != KACalendar::Current;
 }
 
 /******************************************************************************
@@ -1452,10 +1438,10 @@ void AlarmCalendar::checkForDisabledAlarms()
     if (mCalType != RESOURCES)
         return;
     bool disabled = false;
-    KAEvent::List eventlist = events(CalEvent::ACTIVE);
-    for (int i = 0, end = eventlist.count();  i < end;  ++i)
+    const KAEvent::List eventlist = events(CalEvent::ACTIVE);
+    for (const KAEvent* const event : eventlist)
     {
-        if (!eventlist[i]->enabled())
+        if (!event->enabled())
         {
             disabled = true;
             break;
@@ -1471,14 +1457,13 @@ void AlarmCalendar::checkForDisabledAlarms()
 /******************************************************************************
 * Find and note the active alarm with the earliest trigger time for a calendar.
 */
-void AlarmCalendar::findEarliestAlarm(const Akonadi::Collection& collection)
+void AlarmCalendar::findEarliestAlarm(const Resource& resource)
 {
     if (mCalType != RESOURCES)
         return;
-    if (!collection.isValid()
-    ||  !(AkonadiModel::types(collection) & CalEvent::ACTIVE))
+    if (!(resource.alarmTypes() & CalEvent::ACTIVE))
         return;
-    findEarliestAlarm(collection.id());
+    findEarliestAlarm(resource.id());
 }
 
 void AlarmCalendar::findEarliestAlarm(Akonadi::Collection::Id key)
@@ -1495,9 +1480,8 @@ void AlarmCalendar::findEarliestAlarm(Akonadi::Collection::Id key)
     const KAEvent::List& events = rit.value();
     KAEvent* earliest = nullptr;
     KADateTime earliestTime;
-    for (int i = 0, end = events.count();  i < end;  ++i)
+    for (KAEvent* event : events)
     {
-        KAEvent* event = events[i];
         if (event->category() != CalEvent::ACTIVE
         ||  mPendingAlarms.contains(event->id()))
             continue;
@@ -1541,7 +1525,7 @@ KAEvent* AlarmCalendar::earliestAlarm() const
 */
 void AlarmCalendar::setAlarmPending(KAEvent* event, bool pending)
 {
-    QString id = event->id();
+    const QString id = event->id();
     bool wasPending = mPendingAlarms.contains(id);
     qCDebug(KALARM_LOG) << "AlarmCalendar::setAlarmPending:" << id << "," << pending << "(was" << wasPending << ")";
     if (pending)
@@ -1557,7 +1541,7 @@ void AlarmCalendar::setAlarmPending(KAEvent* event, bool pending)
         mPendingAlarms.remove(id);
     }
     // Now update the earliest alarm to trigger for its calendar
-    findEarliestAlarm(AkonadiModel::instance()->collection(*event));
+    findEarliestAlarm(Resources::resourceForEvent(event->id()));
 }
 
 /******************************************************************************
@@ -1585,5 +1569,4 @@ KACalendar::Compat fix(const FileStorage::Ptr& fileStorage)
     return KACalendar::Current;
 }
 
-
 // vim: et sw=4:
