@@ -1,7 +1,7 @@
 /*
  *  editdlg.cpp  -  dialog to create or modify an alarm or alarm template
  *  Program:  kalarm
- *  Copyright © 2001-2018 by David Jarvie <djarvie@kde.org>
+ *  Copyright © 2001-2019 David Jarvie <djarvie@kde.org>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -18,7 +18,6 @@
  *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
-#include "kalarm.h"
 #include "editdlg.h"
 #include "editdlg_p.h"
 #include "editdlgtypes.h"
@@ -47,13 +46,15 @@
 #include "templatepickdlg.h"
 #include "timeedit.h"
 #include "timespinbox.h"
+#include "resources/resources.h"
+#include "kalarm_debug.h"
 
 #include <Libkdepim/MaillistDrag>
 
 #include <KLocalizedString>
 #include <kconfig.h>
 #include <KSharedConfig>
-#include <kwindowsystem.h>
+#include <KWindowSystem>
 
 #include <QLabel>
 #include <QGroupBox>
@@ -67,7 +68,7 @@
 #include <QTimer>
 #include <QDialogButtonBox>
 #include <QLocale>
-#include "kalarm_debug.h"
+#include <QStyle>
 
 using namespace KCal;
 using namespace KAlarmCal;
@@ -134,24 +135,12 @@ EditAlarmDlg* EditAlarmDlg::create(bool Template, const KAEvent* event, bool new
 *   event   != to initialise the dialog to show the specified event's data.
 */
 EditAlarmDlg::EditAlarmDlg(bool Template, KAEvent::SubAction action, QWidget* parent, GetResourceType getResource)
-    : QDialog(parent),
-      mAlarmType(action),
-      mLoadTemplateButton(nullptr),
-      mMainPageShown(false),
-      mRecurPageShown(false),
-      mRecurSetDefaultEndDate(true),
-      mTemplateName(nullptr),
-      mDeferGroup(nullptr),
-      mDeferChangeButton(nullptr),
-      mTimeWidget(nullptr),
-      mShowInKorganizer(nullptr),
-      mDeferGroupHeight(0),
-      mTemplate(Template),
-      mNewAlarm(true),
-      mDesiredReadOnly(false),
-      mReadOnly(false),
-      mShowingMore(true),
-      mSavedEvent(nullptr)
+    : QDialog(parent)
+    , mAlarmType(action)
+    , mTemplate(Template)
+    , mNewAlarm(true)
+    , mDesiredReadOnly(false)
+    , mReadOnly(false)
 {
     init(nullptr, getResource);
     mWindowList.append(this);
@@ -159,25 +148,13 @@ EditAlarmDlg::EditAlarmDlg(bool Template, KAEvent::SubAction action, QWidget* pa
 
 EditAlarmDlg::EditAlarmDlg(bool Template, const KAEvent* event, bool newAlarm, QWidget* parent,
                            GetResourceType getResource, bool readOnly)
-    : QDialog(parent),
-      mAlarmType(event->actionSubType()),
-      mLoadTemplateButton(nullptr),
-      mMainPageShown(false),
-      mRecurPageShown(false),
-      mRecurSetDefaultEndDate(true),
-      mTemplateName(nullptr),
-      mDeferGroup(nullptr),
-      mDeferChangeButton(nullptr),
-      mTimeWidget(nullptr),
-      mShowInKorganizer(nullptr),
-      mDeferGroupHeight(0),
-      mEventId(newAlarm ? QString() : event->id()),
-      mTemplate(Template),
-      mNewAlarm(newAlarm),
-      mDesiredReadOnly(readOnly),
-      mReadOnly(readOnly),
-      mShowingMore(true),
-      mSavedEvent(nullptr)
+    : QDialog(parent)
+    , mAlarmType(event->actionSubType())
+    , mEventId(newAlarm ? QString() : event->id())
+    , mTemplate(Template)
+    , mNewAlarm(newAlarm)
+    , mDesiredReadOnly(readOnly)
+    , mReadOnly(readOnly)
 {
     init(event, getResource);
     mWindowList.append(this);
@@ -190,17 +167,19 @@ void EditAlarmDlg::init(const KAEvent* event, GetResourceType getResource)
         case RES_USE_EVENT_ID:
             if (event)
             {
-                mCollectionItemId = event->itemId();
+                mResourceEventId = event->id();
+                mUseResourceEventId = true;
                 break;
             }
-            // fall through to RES_PROMPT
-            Q_FALLTHROUGH();
+            Q_FALLTHROUGH();   // fall through to RES_PROMPT
         case RES_PROMPT:
-            mCollectionItemId = -1;
+            mResourceEventId.clear();
+            mUseResourceEventId = true;
             break;
         case RES_IGNORE:
         default:
-            mCollectionItemId = -2;
+            mResourceEventId.clear();
+            mUseResourceEventId = false;
             break;
     }
 }
@@ -416,7 +395,7 @@ void EditAlarmDlg::init(const KAEvent* event)
         topLayout->addWidget(mTimeWidget);
     }
 
-    // Optional controls depending on More/Less Options button
+    // Optional controls depending on More/Fewer Options button
     mMoreOptions = new QFrame(mainPage);
     mMoreOptions->setFrameStyle(QFrame::NoFrame);
     topLayout->addWidget(mMoreOptions);
@@ -767,9 +746,9 @@ void EditAlarmDlg::contentsChanged()
 * The data is returned in the supplied KAEvent instance.
 * Reply = false if the only change has been to an existing deferral.
 */
-bool EditAlarmDlg::getEvent(KAEvent& event, Akonadi::Collection& collection)
+bool EditAlarmDlg::getEvent(KAEvent& event, Resource& resource)
 {
-    collection = mCollection;
+    resource = mResource;
     if (mChanged)
     {
         // It's a new event, or the edit controls have changed
@@ -1088,8 +1067,8 @@ bool EditAlarmDlg::validate()
         if (timedRecurrence)
         {
             KAEvent event;
-            Akonadi::Collection c;
-            getEvent(event, c);     // this may adjust mAlarmDateTime
+            Resource res;
+            getEvent(event, res);     // this may adjust mAlarmDateTime
             const KADateTime now = KADateTime::currentDateTime(mAlarmDateTime.timeSpec());
             bool dateOnly = mAlarmDateTime.isDateOnly();
             if ((dateOnly  &&  mAlarmDateTime.date() < now.date())
@@ -1164,26 +1143,26 @@ bool EditAlarmDlg::validate()
     if (!checkText(mAlarmMessage))
         return false;
 
-    mCollection = Akonadi::Collection();
-    // An item ID = -2 indicates that the caller already
-    // knows which collection to use.
-    if (mCollectionItemId >= -1)
+    mResource = Resource();
+    // mUseResourceEventId = false indicates that the caller already knows
+    // which resource to use.
+    if (mUseResourceEventId)
     {
-        if (mCollectionItemId >= 0)
+        if (!mResourceEventId.isEmpty())
         {
-            mCollection = AlarmCalendar::resources()->collectionForEvent(mCollectionItemId);
-            if (mCollection.isValid())
+            mResource = Resources::resourceForEvent(mResourceEventId);
+            if (mResource.isValid())
             {
                 CalEvent::Type type = mTemplate ? CalEvent::TEMPLATE : CalEvent::ACTIVE;
-                if (!(AkonadiModel::instance()->types(mCollection) & type))
-                    mCollection = Akonadi::Collection();   // event may have expired while dialog was open
+                if (!(mResource.alarmTypes() & type))
+                    mResource = Resource();   // event may have expired while dialog was open
             }
         }
         bool cancelled = false;
         CalEvent::Type type = mTemplate ? CalEvent::TEMPLATE : CalEvent::ACTIVE;
-        if (CollectionControlModel::isWritableEnabled(mCollection, type) <= 0)
-            mCollection = CollectionControlModel::destination(type, this, false, &cancelled);
-        if (!mCollection.isValid())
+        if (!mResource.isWritable(type))
+            mResource = CollectionControlModel::destination(type, this, false, &cancelled);
+        if (!mResource.isValid())
         {
             if (!cancelled)
                 KAMessageBox::sorry(this, i18nc("@info", "You must select a calendar to save the alarm in"));
@@ -1247,7 +1226,7 @@ void EditAlarmDlg::slotHelp()
 }
 
 /******************************************************************************
-* Called when the More Options or Less Options buttons are clicked.
+* Called when the More Options or Fewer Options buttons are clicked.
 * Show/hide the optional options and swap the More/Less buttons, and save the
 * new setting as the default from now on.
 */
@@ -1267,7 +1246,7 @@ void EditAlarmDlg::showOptions(bool more)
     if (more)
     {
         mMoreOptions->show();
-        mMoreLessButton->setText(i18nc("@action:Button", "Less Options <<"));
+        mMoreLessButton->setText(i18nc("@action:Button", "Fewer Options <<"));
     }
     else
     {
