@@ -18,7 +18,6 @@
  *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
-#include "kalarm.h"   //krazy:exclude=includes (kalarm.h must be first)
 #include "functions.h"
 #include "functions_p.h"
 
@@ -27,7 +26,6 @@
 #include "alarmcalendar.h"
 #include "alarmtime.h"
 #include "autoqpointer.h"
-#include "alarmlistview.h"
 #include "editdlg.h"
 #include "kalarmapp.h"
 #include "kamail.h"
@@ -38,9 +36,12 @@
 #include "shellprocess.h"
 #include "templatelistview.h"
 #include "templatemenuaction.h"
-
+#include "resources/resources.h"
+#include "resources/eventmodel.h"
 #include "config-kalarm.h"
+#include "kalarm_debug.h"
 
+#include <kalarmcal_version.h>
 #include <kalarmcal/identities.h>
 #include <kalarmcal/kaevent.h>
 
@@ -70,13 +71,11 @@ using namespace KCalendarCore;
 #include <QRegExp>
 #include <QFileDialog>
 #include <QDesktopWidget>
-#include <QtDBus>
+#include <QDBusConnectionInterface>
+#include <QDBusInterface>
 #include <QTimer>
 #include <qglobal.h>
 #include <QStandardPaths>
-#include "kalarm_debug.h"
-
-using namespace Akonadi;
 
 
 namespace
@@ -143,7 +142,7 @@ Private* Private::mInstance = nullptr;
 /******************************************************************************
 * Display a main window with the specified event selected.
 */
-MainWindow* displayMainWindowSelected(Akonadi::Item::Id eventId)
+MainWindow* displayMainWindowSelected(const QString& eventId)
 {
     MainWindow* win = MainWindow::firstWindow();
     if (!win)
@@ -157,13 +156,14 @@ MainWindow* displayMainWindowSelected(Akonadi::Item::Id eventId)
     else
     {
         // There is already a main window, so make it the active window
+#pragma message("Don't hide unless necessary, since it moves the window")
         win->hide();        // in case it's on a different desktop
         win->setWindowState(win->windowState() & ~Qt::WindowMinimized);
         win->show();
         win->raise();
         win->activateWindow();
     }
-    if (win  &&  eventId >= 0)
+    if (win)
         win->selectEvent(eventId);
     return win;
 }
@@ -213,7 +213,7 @@ KToggleAction* createSpreadWindowsAction(QObject* parent)
 *                         error message.
 *             event - is updated with the actual event ID.
 */
-UpdateResult addEvent(KAEvent& event, Collection* calendar, QWidget* msgParent, int options, bool showKOrgErr)
+UpdateResult addEvent(KAEvent& event, Resource* resource, QWidget* msgParent, int options, bool showKOrgErr)
 {
     qCDebug(KALARM_LOG) << "KAlarm::addEvent:" << event.id();
     bool cancelled = false;
@@ -225,7 +225,7 @@ UpdateResult addEvent(KAEvent& event, Collection* calendar, QWidget* msgParent,
         // Save the event details in the calendar file, and get the new event ID
         AlarmCalendar* cal = AlarmCalendar::resources();
         // Note that AlarmCalendar::addEvent() updates 'event'.
-        if (!cal->addEvent(event, msgParent, (options & USE_EVENT_ID), calendar, (options & NO_RESOURCE_PROMPT), &cancelled))
+        if (!cal->addEvent(event, msgParent, (options & USE_EVENT_ID), resource, (options & NO_RESOURCE_PROMPT), &cancelled))
         {
             status.status = UPDATE_FAILED;
         }
@@ -261,40 +261,40 @@ UpdateResult addEvents(QVector<KAEvent>& events, QWidget* msgParent, bool allowK
     if (events.isEmpty())
         return UpdateResult(UPDATE_OK);
     UpdateStatusData status;
-    Collection collection;
     if (!theApp()->checkCalendar())    // ensure calendar is open
         status.status = UPDATE_FAILED;
     else
     {
-        collection = CollectionControlModel::instance()->destination(CalEvent::ACTIVE, msgParent);
-        if (!collection.isValid())
+        Resource resource = CollectionControlModel::destination(CalEvent::ACTIVE, msgParent);
+        if (!resource.isValid())
         {
             qCDebug(KALARM_LOG) << "KAlarm::addEvents: No calendar";
             status.status = UPDATE_FAILED;
         }
-    }
-    if (status.status == UPDATE_OK)
-    {
-        AlarmCalendar* cal = AlarmCalendar::resources();
-        for (int i = 0, end = events.count();  i < end;  ++i)
+        else
         {
-            // Save the event details in the calendar file, and get the new event ID
-            if (!cal->addEvent(events[i], msgParent, false, &collection))
+            AlarmCalendar* cal = AlarmCalendar::resources();
+            for (int i = 0, end = events.count();  i < end;  ++i)
             {
-                status.setError(UPDATE_ERROR);
-                continue;
-            }
-            if (allowKOrgUpdate  &&  events[i].copyToKOrganizer())
-            {
-                UpdateResult st = sendToKOrganizer(events[i]);    // tell KOrganizer to show the event
-                status.korgUpdate(st);
-            }
+                // Save the event details in the calendar file, and get the new event ID
+                KAEvent& event = events[i];
+                if (!cal->addEvent(event, msgParent, false, &resource))
+                {
+                    status.setError(UPDATE_ERROR);
+                    continue;
+                }
+                if (allowKOrgUpdate  &&  event.copyToKOrganizer())
+                {
+                    UpdateResult st = sendToKOrganizer(event);    // tell KOrganizer to show the event
+                    status.korgUpdate(st);
+                }
 
+            }
+            if (status.warnErr == events.count())
+                status.status = UPDATE_FAILED;
+            else if (!cal->save())
+                status.setError(SAVE_FAILED, events.count());  // everything failed
         }
-        if (status.warnErr == events.count())
-            status.status = UPDATE_FAILED;
-        else if (!cal->save())
-            status.setError(SAVE_FAILED, events.count());  // everything failed
     }
 
     if (status.status != UPDATE_OK  &&  msgParent)
@@ -306,7 +306,7 @@ UpdateResult addEvents(QVector<KAEvent>& events, QWidget* msgParent, bool allowK
 * Save the event in the archived calendar and adjust every main window instance.
 * The event's ID is changed to an archived ID if necessary.
 */
-bool addArchivedEvent(KAEvent& event, Collection* collection)
+bool addArchivedEvent(KAEvent& event, Resource* resourceptr)
 {
     qCDebug(KALARM_LOG) << "KAlarm::addArchivedEvent:" << event.id();
     bool archiving = (event.category() == CalEvent::ACTIVE);
@@ -314,7 +314,6 @@ bool addArchivedEvent(KAEvent& event, Collection* collection)
         return false;   // expired alarms aren't being kept
     AlarmCalendar* cal = AlarmCalendar::resources();
     KAEvent newevent(event);
-    newevent.setItemId(-1);    // invalidate the Akonadi item ID since it's a new item
     KAEvent* const newev = &newevent;
     if (archiving)
     {
@@ -322,7 +321,7 @@ bool addArchivedEvent(KAEvent& event, Collection* collection)
         newev->setCreatedDateTime(KADateTime::currentUtcDateTime());   // time stamp to control purging
     }
     // Note that archived resources are automatically saved after changes are made
-    if (!cal->addEvent(newevent, nullptr, false, collection))
+    if (!cal->addEvent(newevent, nullptr, false, resourceptr))
         return false;
     event = *newev;   // update event ID etc.
 
@@ -335,7 +334,7 @@ bool addArchivedEvent(KAEvent& event, Collection* collection)
 * 'event' is updated with the actual event ID.
 * Parameters: promptParent = parent widget for any calendar selection prompt.
 */
-UpdateResult addTemplate(KAEvent& event, Collection* collection, QWidget* msgParent)
+UpdateResult addTemplate(KAEvent& event, Resource* resourceptr, QWidget* msgParent)
 {
     qCDebug(KALARM_LOG) << "KAlarm::addTemplate:" << event.id();
     UpdateStatusData status;
@@ -343,7 +342,7 @@ UpdateResult addTemplate(KAEvent& event, Collection* collection, QWidget* msgPar
     // Add the template to the calendar file
     AlarmCalendar* cal = AlarmCalendar::resources();
     KAEvent newev(event);
-    if (!cal->addEvent(newev, msgParent, false, collection))
+    if (!cal->addEvent(newev, msgParent, false, resourceptr))
         status.status = UPDATE_FAILED;
     else
     {
@@ -450,7 +449,7 @@ UpdateResult updateEvent(KAEvent& event, QWidget* msgParent, bool archiveOnDelet
 UpdateResult updateTemplate(KAEvent& event, QWidget* msgParent)
 {
     AlarmCalendar* cal = AlarmCalendar::resources();
-    KAEvent* newEvent = cal->updateEvent(event);
+    const KAEvent* newEvent = cal->updateEvent(event);
     UpdateStatus status = UPDATE_OK;
     if (!newEvent)
         status = UPDATE_FAILED;
@@ -484,12 +483,12 @@ UpdateResult deleteEvents(QVector<KAEvent>& events, bool archive, QWidget* msgPa
     UpdateStatusData status;
     AlarmCalendar* cal = AlarmCalendar::resources();
     bool deleteWakeFromSuspendAlarm = false;
-    QString wakeFromSuspendId = checkRtcWakeConfig().value(0);
+    const QString wakeFromSuspendId = checkRtcWakeConfig().value(0);
     for (int i = 0, end = events.count();  i < end;  ++i)
     {
         // Save the event details in the calendar file, and get the new event ID
         KAEvent* event = &events[i];
-        QString id = event->id();
+        const QString id = event->id();
 
 
         // Delete the event from the calendar file
@@ -544,12 +543,12 @@ UpdateResult deleteTemplates(const KAEvent::List& events, QWidget* msgParent)
         return UpdateResult(UPDATE_OK);
     UpdateStatusData status;
     AlarmCalendar* cal = AlarmCalendar::resources();
-    for (int i = 0, end = count;  i < end;  ++i)
+    for (const KAEvent* event : events)
     {
         // Update the window lists
         // Delete the template from the calendar file
         AlarmCalendar* cal = AlarmCalendar::resources();
-        if (!cal->deleteEvent(*events[i], false))   // don't save calendar after deleting
+        if (!cal->deleteEvent(*event, false))   // don't save calendar after deleting
             status.setError(UPDATE_ERROR);
     }
 
@@ -576,28 +575,31 @@ void deleteDisplayEvent(const QString& eventID)
 /******************************************************************************
 * Undelete archived alarms, and update every main window instance.
 * The archive bit is set to ensure that they get re-archived if deleted again.
-* 'ineligibleIDs' is filled in with the IDs of any ineligible events.
+* Parameters:
+*   calendar - the active alarms calendar to restore the alarms into, or null
+*              to use the default way of determining the active alarm calendar.
+*   ineligibleIDs - will be filled in with the IDs of any ineligible events.
 */
-UpdateResult reactivateEvent(KAEvent& event, Collection* calendar, QWidget* msgParent, bool showKOrgErr)
+UpdateResult reactivateEvent(KAEvent& event, Resource* resourceptr, QWidget* msgParent, bool showKOrgErr)
 {
     QVector<EventId> ids;
     QVector<KAEvent> events(1, event);
-    return reactivateEvents(events, ids, calendar, msgParent, showKOrgErr);
+    return reactivateEvents(events, ids, resourceptr, msgParent, showKOrgErr);
 }
 
-UpdateResult reactivateEvents(QVector<KAEvent>& events, QVector<EventId>& ineligibleIDs, Collection* col, QWidget* msgParent, bool showKOrgErr)
+UpdateResult reactivateEvents(QVector<KAEvent>& events, QVector<EventId>& ineligibleIDs, Resource* resourceptr, QWidget* msgParent, bool showKOrgErr)
 {
     qCDebug(KALARM_LOG) << "KAlarm::reactivateEvents:" << events.count();
     ineligibleIDs.clear();
     if (events.isEmpty())
         return UpdateResult(UPDATE_OK);
     UpdateStatusData status;
-    Collection collection;
-    if (col)
-        collection = *col;
-    if (!collection.isValid())
-        collection = CollectionControlModel::instance()->destination(CalEvent::ACTIVE, msgParent);
-    if (!collection.isValid())
+    Resource resource;
+    if (resourceptr)
+        resource = *resourceptr;
+    if (!resource.isValid())
+        resource = CollectionControlModel::destination(CalEvent::ACTIVE, msgParent);
+    if (!resource.isValid())
     {
         qCDebug(KALARM_LOG) << "KAlarm::reactivateEvents: No calendar";
         status.setError(UPDATE_FAILED, events.count());
@@ -628,7 +630,7 @@ UpdateResult reactivateEvents(QVector<KAEvent>& events, QVector<EventId>& inelig
 
             // Save the event details in the calendar file.
             // This converts the event ID.
-            if (!cal->addEvent(newevent, msgParent, true, &collection))
+            if (!cal->addEvent(newevent, msgParent, true, &resource))
             {
                 status.setError(UPDATE_ERROR);
                 continue;
@@ -639,7 +641,6 @@ UpdateResult reactivateEvents(QVector<KAEvent>& events, QVector<EventId>& inelig
                 status.korgUpdate(st);
             }
 
-
             if (cal->event(EventId(*event))  // no error if event doesn't exist in archived resource
             &&  !cal->deleteEvent(*event, false))   // don't save calendar after deleting
                 status.setError(UPDATE_ERROR);
@@ -669,7 +670,7 @@ UpdateResult enableEvents(QVector<KAEvent>& events, bool enable, QWidget* msgPar
     UpdateStatusData status;
     AlarmCalendar* cal = AlarmCalendar::resources();
     bool deleteWakeFromSuspendAlarm = false;
-    QString wakeFromSuspendId = checkRtcWakeConfig().value(0);
+    const QString wakeFromSuspendId = checkRtcWakeConfig().value(0);
     for (int i = 0, end = events.count();  i < end;  ++i)
     {
         KAEvent* event = &events[i];
@@ -682,7 +683,7 @@ UpdateResult enableEvents(QVector<KAEvent>& events, bool enable, QWidget* msgPar
                 deleteWakeFromSuspendAlarm = true;
 
             // Update the event in the calendar file
-            KAEvent* newev = cal->updateEvent(event);
+            const KAEvent* newev = cal->updateEvent(event);
             if (!newev)
                 qCCritical(KALARM_LOG) << "KAlarm::enableEvents: Error updating event in calendar:" << event->id();
             else
@@ -725,10 +726,10 @@ void purgeArchive(int purgeDays)
         return;
     qCDebug(KALARM_LOG) << "KAlarm::purgeArchive:" << purgeDays;
     const QDate cutoff = KADateTime::currentLocalDate().addDays(-purgeDays);
-    Collection collection = CollectionControlModel::getStandard(CalEvent::ARCHIVED);
-    if (!collection.isValid())
+    const Resource resource = Resources::getStandard(CalEvent::ARCHIVED);
+    if (!resource.isValid())
         return;
-    KAEvent::List events = AlarmCalendar::resources()->events(collection);
+    KAEvent::List events = AlarmCalendar::resources()->events(resource);
     for (int i = 0;  i < events.count();  )
     {
         if (purgeDays  &&  events.at(i)->createdDateTime().date() >= cutoff)
@@ -752,14 +753,14 @@ QVector<KAEvent> getSortedActiveEvents(QObject* parent, AlarmListModel** model)
         model = &mdl;
     if (!*model)
     {
-        *model = new AlarmListModel(parent);
+        *model = AlarmListModel::create<AkonadiModel>(parent);
         (*model)->setEventTypeFilter(CalEvent::ACTIVE);
         (*model)->sort(AlarmListModel::TimeColumn);
     }
     QVector<KAEvent> result;
     for (int i = 0, count = (*model)->rowCount();  i < count;  ++i)
     {
-        KAEvent event = (*model)->event(i);
+        const KAEvent event = (*model)->event(i);
         if (event.enabled()  &&  !event.expired())
             result += event;
     }
@@ -897,11 +898,11 @@ void PrivateNewAlarmDlg::okClicked()
 void PrivateNewAlarmDlg::accept(EditAlarmDlg* editDlg)
 {
     KAEvent event;
-    Collection calendar;
-    editDlg->getEvent(event, calendar);
+    Resource resource;
+    editDlg->getEvent(event, resource);
 
     // Add the alarm to the displayed lists and to the calendar file
-    UpdateResult status = addEvent(event, &calendar, editDlg);
+    const UpdateResult status = addEvent(event, &resource, editDlg);
     switch (status.status)
     {
         case UPDATE_FAILED:
@@ -915,7 +916,7 @@ void PrivateNewAlarmDlg::accept(EditAlarmDlg* editDlg)
         default:
             break;
     }
-    Undo::saveAdd(event, calendar);
+    Undo::saveAdd(event, resource);
 
     outputAlarmWarnings(editDlg, &event);
 
@@ -978,8 +979,8 @@ QString currentDesktopIdentityName()
 Desktop currentDesktopIdentity()
 {
     const QString desktop = currentDesktopIdentityName();
-    if (desktop == QStringLiteral("KDE"))    return Desktop::Kde;
-    if (desktop == QStringLiteral("Unity"))  return Desktop::Unity;
+    if (desktop == QLatin1String("KDE"))    return Desktop::Kde;
+    if (desktop == QLatin1String("Unity"))  return Desktop::Unity;
     return Desktop::Other;
 }
 
@@ -988,16 +989,20 @@ Desktop currentDesktopIdentity()
 * if so, delete it from the config if it has expired.
 * If 'checkExists' is true, the config entry will only be returned if the
 * event exists.
-* Reply = config entry: [0] = event's collection ID (Akonadi only),
+* Reply = config entry: [0] = event's resource ID,
 *                       [1] = event ID,
-*                       [2] = trigger time (time_t).
+*                       [2] = trigger time (int64 seconds since epoch).
 *       = empty list if none or expired.
 */
 QStringList checkRtcWakeConfig(bool checkEventExists)
 {
     KConfigGroup config(KSharedConfig::openConfig(), "General");
     const QStringList params = config.readEntry("RtcWake", QStringList());
+#if KALARMCAL_VERSION >= QT_VERSION_CHECK(5,12,1)
+    if (params.count() == 3  &&  params[2].toLongLong() > KADateTime::currentUtcDateTime().toSecsSinceEpoch())
+#else
     if (params.count() == 3  &&  params[2].toUInt() > KADateTime::currentUtcDateTime().toTime_t())
+#endif
     {
         if (checkEventExists  &&  !AlarmCalendar::getEvent(EventId(params[0].toLongLong(), params[1])))
             return QStringList();
@@ -1094,7 +1099,7 @@ namespace
 */
 void editNewTemplate(EditAlarmDlg::Type type, const KAEvent* preset, QWidget* parent)
 {
-    if (CollectionControlModel::enabledCollections(CalEvent::TEMPLATE, true).isEmpty())
+    if (Resources::enabledResources(CalEvent::TEMPLATE, true).isEmpty())
     {
         KAMessageBox::sorry(parent, i18nc("@info", "You must enable a template calendar to save the template in"));
         return;
@@ -1110,12 +1115,12 @@ void editNewTemplate(EditAlarmDlg::Type type, const KAEvent* preset, QWidget* pa
     if (editDlg->exec() == QDialog::Accepted)
     {
         KAEvent event;
-        Akonadi::Collection calendar;
-        editDlg->getEvent(event, calendar);
+        Resource resource;
+        editDlg->getEvent(event, resource);
 
         // Add the template to the displayed lists and to the calendar file
-        KAlarm::addTemplate(event, &calendar, editDlg);
-        Undo::saveAdd(event, calendar);
+        KAlarm::addTemplate(event, &resource, editDlg);
+        Undo::saveAdd(event, resource);
     }
 }
 
@@ -1129,12 +1134,12 @@ namespace KAlarm
 */
 void editAlarm(KAEvent* event, QWidget* parent)
 {
-    if (event->expired()  ||  AlarmCalendar::resources()->eventReadOnly(event->itemId()))
+    if (event->expired()  ||  AlarmCalendar::resources()->eventReadOnly(event->id()))
     {
         viewAlarm(event, parent);
         return;
     }
-    EventId id(*event);
+    const EventId id(*event);
     // Use AutoQPointer to guard against crash on application exit while
     // the dialogue is still open. It prevents double deletion (both on
     // deletion of parent, and on return from this function).
@@ -1149,11 +1154,11 @@ void editAlarm(KAEvent* event, QWidget* parent)
             return;
         }
         KAEvent newEvent;
-        Collection calendar;
-        bool changeDeferral = !editDlg->getEvent(newEvent, calendar);
+        Resource resource;
+        bool changeDeferral = !editDlg->getEvent(newEvent, resource);
 
         // Update the event in the displays and in the calendar file
-        Undo::Event undo(*event, calendar);
+        const Undo::Event undo(*event, resource);
         if (changeDeferral)
         {
             // The only change has been to an existing deferral
@@ -1162,7 +1167,7 @@ void editAlarm(KAEvent* event, QWidget* parent)
         }
         else
         {
-            UpdateResult status = modifyEvent(*event, newEvent, editDlg);
+            const UpdateResult status = modifyEvent(*event, newEvent, editDlg);
             if (status.status != UPDATE_OK  &&  status.status <= UPDATE_KORG_ERR)
                 displayKOrgUpdateError(editDlg, ERR_MODIFY, status);
         }
@@ -1183,13 +1188,13 @@ bool editAlarmById(const EventId& id, QWidget* parent)
     KAEvent* event = AlarmCalendar::resources()->event(id, true);
     if (!event)
     {
-        if (id.collectionId() != -1)    
+        if (id.collectionId() != -1)
             qCWarning(KALARM_LOG) << "KAlarm::editAlarmById: Event ID not found, or duplicated:" << eventID;
         else
             qCWarning(KALARM_LOG) << "KAlarm::editAlarmById: Event ID not found:" << eventID;
         return false;
     }
-    if (AlarmCalendar::resources()->eventReadOnly(event->itemId()))
+    if (AlarmCalendar::resources()->eventReadOnly(event->id()))
     {
         qCCritical(KALARM_LOG) << "KAlarm::editAlarmById:" << eventID << ": read-only";
         return false;
@@ -1213,7 +1218,7 @@ bool editAlarmById(const EventId& id, QWidget* parent)
 */
 void editTemplate(KAEvent* event, QWidget* parent)
 {
-    if (AlarmCalendar::resources()->eventReadOnly(event->itemId()))
+    if (AlarmCalendar::resources()->eventReadOnly(event->id()))
     {
         // The template is read-only, so make the dialogue read-only.
         // Use AutoQPointer to guard against crash on application exit while
@@ -1230,15 +1235,14 @@ void editTemplate(KAEvent* event, QWidget* parent)
     if (editDlg->exec() == QDialog::Accepted)
     {
         KAEvent newEvent;
-        Akonadi::Collection calendar;
-        editDlg->getEvent(newEvent, calendar);
-        QString id = event->id();
+        Resource resource;
+        editDlg->getEvent(newEvent, resource);
+        const QString id = event->id();
         newEvent.setEventId(id);
-        newEvent.setCollectionId(event->collectionId());
-        newEvent.setItemId(event->itemId());
+        newEvent.setResourceId(event->resourceId());
 
         // Update the event in the displays and in the calendar file
-        Undo::Event undo(*event, calendar);
+        const Undo::Event undo(*event, resource);
         updateTemplate(newEvent, editDlg);
         Undo::saveEdit(undo, newEvent);
     }
@@ -1261,27 +1265,27 @@ void viewAlarm(const KAEvent* event, QWidget* parent)
 * in an alarm message window.
 * Updates the alarm calendar and closes the dialog.
 */
-void updateEditedAlarm(EditAlarmDlg* editDlg, KAEvent& event, Collection& calendar)
+void updateEditedAlarm(EditAlarmDlg* editDlg, KAEvent& event, Resource& resource)
 {
     qCDebug(KALARM_LOG) << "KAlarm::updateEditedAlarm";
     KAEvent newEvent;
-    Akonadi::Collection cal;
-    editDlg->getEvent(newEvent, cal);
+    Resource res;
+    editDlg->getEvent(newEvent, res);
 
     // Update the displayed lists and the calendar file
     UpdateResult status;
     if (AlarmCalendar::resources()->event(EventId(event)))
     {
         // The old alarm hasn't expired yet, so replace it
-        Undo::Event undo(event, calendar);
+        const Undo::Event undo(event, resource);
         status = modifyEvent(event, newEvent, editDlg);
         Undo::saveEdit(undo, newEvent);
     }
     else
     {
         // The old event has expired, so simply create a new one
-        status = addEvent(newEvent, &calendar, editDlg);
-        Undo::saveAdd(newEvent, calendar);
+        status = addEvent(newEvent, &resource, editDlg);
+        Undo::saveAdd(newEvent, resource);
     }
 
     if (status.status != UPDATE_OK  &&  status.status <= UPDATE_KORG_ERR)
@@ -1298,11 +1302,10 @@ void updateEditedAlarm(EditAlarmDlg* editDlg, KAEvent& event, Collection& calend
 KAEvent::List templateList()
 {
     KAEvent::List templates;
-    bool includeCmdAlarms = ShellProcess::authorised();
-    KAEvent::List events = AlarmCalendar::resources()->events(CalEvent::TEMPLATE);
-    for (int i = 0, end = events.count();  i < end;  ++i)
+    const bool includeCmdAlarms = ShellProcess::authorised();
+    const KAEvent::List events = AlarmCalendar::resources()->events(CalEvent::TEMPLATE);
+    for (KAEvent* event : events)
     {
-        KAEvent* event = events[i];
         if (includeCmdAlarms  ||  !(event->actionTypes() & KAEvent::ACT_COMMAND))
             templates.append(event);
     }
@@ -1358,10 +1361,9 @@ void refreshAlarmsIfQueued()
         AlarmCalendar::resources()->reload();
 
         // Close any message windows for alarms which are now disabled
-        KAEvent::List events = AlarmCalendar::resources()->events(CalEvent::ACTIVE);
-        for (int i = 0, end = events.count();  i < end;  ++i)
+        const KAEvent::List events = AlarmCalendar::resources()->events(CalEvent::ACTIVE);
+        for (KAEvent* event : events)
         {
-            KAEvent* event = events[i];
             if (!event->enabled()  &&  (event->actionTypes() & KAEvent::ACT_DISPLAY))
             {
                 MessageWin* win = MessageWin::findEvent(EventId(*event));
@@ -1381,15 +1383,14 @@ void refreshAlarmsIfQueued()
 */
 QString runKMail()
 {
-    QDBusReply<bool> reply = QDBusConnection::sessionBus().interface()->isServiceRegistered(KMAIL_DBUS_SERVICE);
+    const QDBusReply<bool> reply = QDBusConnection::sessionBus().interface()->isServiceRegistered(KMAIL_DBUS_SERVICE);
     if (!reply.isValid()  ||  !reply.value())
     {
         // Program is not already running, so start it
-        QString errmsg;
-        QDBusReply<void> startReply = QDBusConnection::sessionBus().interface()->startService(KMAIL_DBUS_SERVICE);
+        const QDBusReply<void> startReply = QDBusConnection::sessionBus().interface()->startService(KMAIL_DBUS_SERVICE);
         if (!startReply.isValid())
         {
-            QString errmsg = startReply.error().message();
+            const QString errmsg = startReply.error().message();
             qCCritical(KALARM_LOG) << "Couldn't start KMail (" << errmsg << ")";
             return xi18nc("@info", "Unable to start <application>KMail</application><nl/>(<message>%1</message>)", errmsg);
         }
@@ -1425,7 +1426,7 @@ bool dontShowErrors(const EventId& eventId, const QString& tag)
 {
     if (tag.isEmpty())
         return false;
-    QStringList tags = dontShowErrors(eventId);
+    const QStringList tags = dontShowErrors(eventId);
     return tags.indexOf(tag) >= 0;
 }
 
@@ -1577,7 +1578,7 @@ bool showFileErrMessage(const QString& filename, FileErr err, FileErr blankError
     {
         // If file is a local file, remove "file://" from name
         QString file = filename;
-        QRegExp f(QStringLiteral("^file:/+"));
+        const QRegExp f(QStringLiteral("^file:/+"));
         if (f.indexIn(file) >= 0)
             file = file.mid(f.matchedLength() - 1);
 
@@ -1621,22 +1622,24 @@ QString pathOrUrl(const QString& url)
 /******************************************************************************
 * Display a modal dialog to choose an existing file, initially highlighting
 * any specified file.
+* @param file        Updated with the file which was selected, or empty if no file
+*                    was selected.
 * @param initialFile The file to initially highlight - must be a full path name or URL.
 * @param defaultDir The directory to start in if @p initialFile is empty. If empty,
 *                   the user's home directory will be used. Updated to the
 *                   directory containing the selected file, if a file is chosen.
 * @param existing true to return only existing files, false to allow new ones.
-* Reply = URL selected.
-*       = empty, non-null string if no file was selected.
-*       = null string if dialogue was deleted while visible (indicating that
+* Reply = true if 'file' value can be used.
+*       = false if the dialogue was deleted while visible (indicating that
 *         the parent widget was probably also deleted).
 */
-QString browseFile(const QString& caption, QString& defaultDir, const QString& initialFile,
-                   const QString& filter, bool existing, QWidget* parent)
+bool browseFile(QString& file, const QString& caption, QString& defaultDir,
+                const QString& initialFile, const QString& filter, bool existing, QWidget* parent)
 {
-    QString initialDir = !initialFile.isEmpty() ? QString(initialFile).remove(QRegExp(QLatin1String("/[^/]*$")))
-                       : !defaultDir.isEmpty()  ? defaultDir
-                       :                          QDir::homePath();
+    file.clear();
+    const QString initialDir = !initialFile.isEmpty() ? QString(initialFile).remove(QRegExp(QLatin1String("/[^/]*$")))
+                             : !defaultDir.isEmpty()  ? defaultDir
+                             :                          QDir::homePath();
     // Use AutoQPointer to guard against crash on application exit while
     // the dialogue is still open. It prevents double deletion (both on
     // deletion of parent, and on return from this function).
@@ -1646,14 +1649,15 @@ QString browseFile(const QString& caption, QString& defaultDir, const QString& i
     if (!initialFile.isEmpty())
         fileDlg->selectFile(initialFile);
     if (fileDlg->exec() != QDialog::Accepted)
-        return fileDlg ? QStringLiteral("") : QString();  // return null only if dialog was deleted
+        return static_cast<bool>(fileDlg);   // return false if dialog was deleted
     const QList<QUrl> urls = fileDlg->selectedUrls();
     if (urls.isEmpty())
-        return QStringLiteral("");   // return empty, non-null string
+        return true;
     const QUrl& url = urls[0];
     defaultDir = url.isLocalFile() ? KIO::upUrl(url).toLocalFile() : url.adjusted(QUrl::RemoveFilename).path();
     bool localOnly = true;
-    return localOnly ? url.toDisplayString(QUrl::PreferLocalFile) : url.toDisplayString();
+    file = localOnly ? url.toDisplayString(QUrl::PreferLocalFile) : url.toDisplayString();
+    return true;
 }
 
 /******************************************************************************
@@ -1667,11 +1671,11 @@ QString browseFile(const QString& caption, QString& defaultDir, const QString& i
 */
 QString conversionPrompt(const QString& calendarName, const QString& calendarVersion, bool whole)
 {
-    QString msg = whole
-                ? xi18nc("@info", "Calendar <resource>%1</resource> is in an old format (<application>KAlarm</application> version %2), "
+    const QString msg = whole
+                ? xi18n("Calendar <resource>%1</resource> is in an old format (<application>KAlarm</application> version %2), "
                        "and will be read-only unless you choose to update it to the current format.",
                        calendarName, calendarVersion)
-                : xi18nc("@info", "Some or all of the alarms in calendar <resource>%1</resource> are in an old <application>KAlarm</application> format, "
+                : xi18n("Some or all of the alarms in calendar <resource>%1</resource> are in an old <application>KAlarm</application> format, "
                        "and will be read-only unless you choose to update them to the current format.",
                        calendarName);
     return xi18nc("@info", "<para>%1</para><para>"
@@ -1768,9 +1772,9 @@ KAlarm::UpdateResult sendToKOrganizer(const KAEvent& event)
             break;
         case KAEvent::ACT_EMAIL:
         {
-            QString from = event.emailFromId()
-                         ? Identities::identityManager()->identityForUoid(event.emailFromId()).fullEmailAddr()
-                         : Preferences::emailAddress();
+            const QString from = event.emailFromId()
+                               ? Identities::identityManager()->identityForUoid(event.emailFromId()).fullEmailAddr()
+                               : Preferences::emailAddress();
             AlarmText atext;
             atext.setEmail(event.emailAddresses(QStringLiteral(", ")), from, QString(), QString(), event.emailSubject(), QString());
             kcalEvent->setSummary(atext.displayText());
@@ -1845,7 +1849,8 @@ KAlarm::UpdateResult runKOrganizer()
     // the load() method doesn't exist. This call starts korganizer if needed, too.
     QDBusInterface iface(KORG_DBUS_SERVICE, QStringLiteral(KORG_DBUS_LOAD_PATH), QStringLiteral("org.kde.PIMUniqueApplication"));
     QDBusReply<bool> reply = iface.call(QStringLiteral("load"));
-    if ((!reply.isValid() || !reply.value()) && iface.lastError().type() != QDBusError::UnknownMethod)
+    if ((!reply.isValid() || !reply.value())
+    &&  iface.lastError().type() != QDBusError::UnknownMethod)
     {
         status.set(KAlarm::UPDATE_KORG_ERR, iface.lastError().message());
         qCWarning(KALARM_LOG) << "Loading KOrganizer failed:" << status.message;
