@@ -18,7 +18,6 @@
  *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
-#include "kalarm.h"
 #include "mainwindow.h"
 
 #include "alarmcalendar.h"
@@ -26,6 +25,7 @@
 #include "autoqpointer.h"
 #include "alarmlistview.h"
 #include "birthdaydlg.h"
+#include "collectionmodel.h"
 #include "functions.h"
 #include "kalarmapp.h"
 #include "kamail.h"
@@ -40,6 +40,8 @@
 #include "templatepickdlg.h"
 #include "traywindow.h"
 #include "wakedlg.h"
+#include "resources/resources.h"
+#include "resources/eventmodel.h"
 #include "kalarm_debug.h"
 
 #include <kalarmcal/alarmtext.h>
@@ -53,7 +55,6 @@
 #include <AkonadiWidgets/controlgui.h>
 #include <KCalendarCore/MemoryCalendar>
 #include <KCalUtils/kcalutils/icaldrag.h>
-using namespace Akonadi;
 using namespace KCalendarCore;
 using namespace KCalUtils;
 #include <KAboutData>
@@ -83,6 +84,7 @@ using namespace KCalUtils;
 #include <QMimeDatabase>
 #include <QInputDialog>
 #include <QUrl>
+#include <QUrlQuery>
 #include <QSystemTrayIcon>
 
 using namespace KAlarmCal;
@@ -126,11 +128,7 @@ MainWindow* MainWindow::create(bool restored)
 }
 
 MainWindow::MainWindow(bool restored)
-    : MainWindowBase(nullptr, Qt::WindowContextHelpButtonHint),
-      mResourcesWidth(-1),
-      mHiddenTrayParent(false),
-      mShown(false),
-      mResizing(false)
+    : MainWindowBase(nullptr, Qt::WindowContextHelpButtonHint)
 {
     qCDebug(KALARM_LOG) << "MainWindow:";
     setAttribute(Qt::WA_DeleteOnClose);
@@ -161,7 +159,7 @@ MainWindow::MainWindow(bool restored)
     mSplitter->setStretchFactor(1, 1);
 
     // Create the alarm list widget
-    mListFilterModel = new AlarmListModel(this);
+    mListFilterModel = AlarmListModel::create<AkonadiModel>(this);
     mListFilterModel->setEventTypeFilter(mShowArchived ? CalEvent::ACTIVE | CalEvent::ARCHIVED : CalEvent::ACTIVE);
     mListView = new AlarmListView(WINDOW_NAME, mSplitter);
     mListView->setModel(mListFilterModel);
@@ -170,8 +168,8 @@ MainWindow::MainWindow(bool restored)
     connect(mListView->selectionModel(), &QItemSelectionModel::selectionChanged, this, &MainWindow::slotSelection);
     connect(mListView, &AlarmListView::contextMenuRequested, this, &MainWindow::slotContextMenuRequested);
     connect(mListView, &AlarmListView::columnsVisibleChanged, this, &MainWindow::slotAlarmListColumnsChanged);
-    connect(AkonadiModel::instance(), &AkonadiModel::collectionStatusChanged,
-                       this, &MainWindow::slotCalendarStatusChanged);
+    connect(Resources::instance(), &Resources::settingsChanged,
+                             this, &MainWindow::slotCalendarStatusChanged);
     connect(mResourceSelector, &ResourceSelector::resized, this, &MainWindow::resourcesResized);
     mListView->installEventFilter(this);
     initActions();
@@ -637,10 +635,10 @@ void MainWindow::updateKeepArchived(int days)
 /******************************************************************************
 * Select an alarm in the displayed list.
 */
-void MainWindow::selectEvent(Akonadi::Item::Id eventId)
+void MainWindow::selectEvent(const QString& eventId)
 {
     mListView->clearSelection();
-    QModelIndex index = mListFilterModel->eventIndex(eventId);
+    const QModelIndex index = mListFilterModel->eventIndex(eventId);
     if (index.isValid())
     {
         mListView->select(index);
@@ -736,14 +734,13 @@ void MainWindow::slotDelete(bool force)
 
     // Remove any events which have just triggered, from the list to delete.
     Undo::EventList undos;
-    AlarmCalendar* resources = AlarmCalendar::resources();
     for (int i = 0;  i < events.count();  )
     {
-        Akonadi::Collection c = resources->collectionForEvent(events[i].itemId());
-        if (!c.isValid())
+        Resource res = Resources::resourceForEvent(events[i].id());
+        if (!res.isValid())
             events.remove(i);
         else
-            undos.append(events[i++], c);
+            undos.append(events[i++], res);
     }
 
     if (events.isEmpty())
@@ -771,13 +768,10 @@ void MainWindow::slotReactivate()
     KAlarm::reactivateEvents(events, ineligibleIDs, nullptr, this);
 
     // Create the undo list, excluding ineligible events
-    AlarmCalendar* resources = AlarmCalendar::resources();
     for (int i = 0, end = events.count();  i < end;  ++i)
     {
         if (!ineligibleIDs.contains(EventId(events[i])))
-        {
-            undos.append(events[i], resources->collectionForEvent(events[i].itemId()));
-        }
+            undos.append(events[i], Resources::resourceForEvent(events[i].id()));
     }
     Undo::saveReactivates(undos);
 }
@@ -883,12 +877,8 @@ void MainWindow::slotBirthdays()
             KAlarm::UpdateResult status = KAlarm::addEvents(events, dlg, true, true);
 
             Undo::EventList undos;
-            AlarmCalendar* resources = AlarmCalendar::resources();
             for (int i = 0, end = events.count();  i < end;  ++i)
-            {
-                Akonadi::Collection c = resources->collectionForEvent(events[i].itemId());
-                undos.append(events[i], c);
-            }
+                undos.append(events[i], Resources::resourceForEvent(events[i].id()));
             Undo::saveAdds(undos, i18nc("@info", "Import birthdays"));
 
             if (status != KAlarm::UPDATE_FAILED)
@@ -1218,7 +1208,7 @@ void MainWindow::executeDropEvent(MainWindow* win, QDropEvent* e)
     QList<QUrl>        urls;
     MemoryCalendar::Ptr calendar(new MemoryCalendar(Preferences::timeSpecAsZone()));
 #ifndef NDEBUG
-    QString fmts = data->formats().join(QStringLiteral(", "));
+    QString fmts = data->formats().join(QLatin1String(", "));
     qCDebug(KALARM_LOG) << "MainWindow::executeDropEvent:" << fmts;
 #endif
 
@@ -1261,7 +1251,7 @@ void MainWindow::executeDropEvent(MainWindow* win, QDropEvent* e)
             return;
         const KPIM::MailSummary& summary = mailList.at(0);
         QDateTime dt;
-        dt.setTime_t(summary.date());
+        dt.setSecsSinceEpoch(summary.date());
         const QString body = KAMail::getMailBody(summary.serialNumber());
         alarmText.setEmail(summary.to(), summary.from(), QString(),
                            QLocale().toString(dt), summary.subject(),
@@ -1343,18 +1333,18 @@ void MainWindow::executeDropEvent(MainWindow* win, QDropEvent* e)
     else if (!(urls = data->urls()).isEmpty())
     {
         const QUrl& url(urls.at(0));
-        const Item item = Item::fromUrl(url);
+        const Akonadi::Item item = Akonadi::Item::fromUrl(url);
         if (item.isValid())
         {
             // It's an Akonadi item
             qCDebug(KALARM_LOG) << "MainWindow::executeDropEvent: Akonadi item" << item.id();
-            if (QUrlQuery(url).queryItemValue(QStringLiteral("type")) == QStringLiteral("message/rfc822"))
+            if (QUrlQuery(url).queryItemValue(QStringLiteral("type")) == QLatin1String("message/rfc822"))
             {
                 // It's an email held in Akonadi
                 qCDebug(KALARM_LOG) << "MainWindow::executeDropEvent: Akonadi email";
-                ItemFetchJob* job = new ItemFetchJob(item);
+                Akonadi::ItemFetchJob* job = new Akonadi::ItemFetchJob(item);
                 job->fetchScope().fetchFullPayload();
-                Item::List items;
+                Akonadi::Item::List items;
                 if (job->exec())
                     items = job->items();
                 if (items.isEmpty())
@@ -1362,7 +1352,7 @@ void MainWindow::executeDropEvent(MainWindow* win, QDropEvent* e)
                     qCWarning(KALARM_LOG) << "MainWindow::executeDropEvent: Akonadi item" << item.id() << "not found";
                     return;
                 }
-                const Item& it = items.at(0);
+                const Akonadi::Item& it = items.at(0);
                 if (!it.isValid()  ||  !it.hasPayload<KMime::Message::Ptr>())
                 {
                     qCWarning(KALARM_LOG) << "MainWindow::executeDropEvent: invalid email";
@@ -1386,7 +1376,7 @@ void MainWindow::executeDropEvent(MainWindow* win, QDropEvent* e)
             // Try to find the mime type of the file, without downloading a remote file
             QMimeDatabase mimeDb;
             const QString mimeTypeName = mimeDb.mimeTypeForUrl(url).name();
-            action = mimeTypeName.startsWith(QStringLiteral("audio/")) ? KAEvent::AUDIO : KAEvent::FILE;
+            action = mimeTypeName.startsWith(QLatin1String("audio/")) ? KAEvent::AUDIO : KAEvent::FILE;
             alarmText.setText(url.toDisplayString());
         }
     }
@@ -1435,8 +1425,8 @@ void MainWindow::executeDropEvent(MainWindow* win, QDropEvent* e)
 void MainWindow::slotCalendarStatusChanged()
 {
     // Find whether there are any writable calendars
-    bool active  = !CollectionControlModel::enabledCollections(CalEvent::ACTIVE, true).isEmpty();
-    bool templat = !CollectionControlModel::enabledCollections(CalEvent::TEMPLATE, true).isEmpty();
+    bool active  = !Resources::enabledResources(CalEvent::ACTIVE, true).isEmpty();
+    bool templat = !Resources::enabledResources(CalEvent::TEMPLATE, true).isEmpty();
     for (int i = 0, end = mWindowList.count();  i < end;  ++i)
     {
         MainWindow* w = mWindowList[i];
@@ -1482,7 +1472,7 @@ void MainWindow::slotSelection()
         bool expired = event->expired();
         if (!expired)
             allArchived = false;
-        if (resources->eventReadOnly(event->itemId()))
+        if (resources->eventReadOnly(event->id()))
             readOnly = true;
         if (enableReactivate
         &&  (!expired  ||  !event->occursAfter(now, true)))
@@ -1502,7 +1492,7 @@ void MainWindow::slotSelection()
     }
 
     qCDebug(KALARM_LOG) << "MainWindow::slotSelection: true";
-    mActionCreateTemplate->setEnabled((count == 1) && !CollectionControlModel::enabledCollections(CalEvent::TEMPLATE, true).isEmpty());
+    mActionCreateTemplate->setEnabled((count == 1) && !Resources::enabledResources(CalEvent::TEMPLATE, true).isEmpty());
     mActionExportAlarms->setEnabled(true);
     mActionExport->setEnabled(true);
     mActionCopy->setEnabled(active && count == 1);
@@ -1616,8 +1606,8 @@ void MainWindow::editAlarmOk()
         return;
     if (dlg->result() != QDialog::Accepted)
         return;
-    Akonadi::Collection c = AkonadiModel::instance()->collection(event);
-    KAlarm::updateEditedAlarm(dlg, event, c);
+    Resource res = Resources::resourceForEvent(event.id());
+    KAlarm::updateEditedAlarm(dlg, event, res);
 }
 
 /******************************************************************************
