@@ -18,10 +18,9 @@
  *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
-#include "config-kalarm.h"
-#include "kalarm.h"
-#include "messagewin_p.h"
 #include "messagewin.h"
+#include "messagewin_p.h"
+#include "config-kalarm.h"
 
 #include "alarmcalendar.h"
 #include "autoqpointer.h"
@@ -37,11 +36,14 @@
 #include "pushbutton.h"
 #include "shellprocess.h"
 #include "synchtimer.h"
+#include "resources/resources.h"
+#include "kalarm_debug.h"
 
 #include <kpimtextedit/texttospeech.h>
 #include <AkonadiCore/itemfetchjob.h>
 #include <AkonadiCore/itemfetchscope.h>
 
+#include <kwindowsystem_version.h>
 #include <KAboutData>
 #include <kstandardguiitem.h>
 #include <KLocalizedString>
@@ -84,15 +86,13 @@
 #include <QMutexLocker>
 #include <QMimeDatabase>
 #include <QUrl>
-#include <QLocale>
-#include "kalarm_debug.h"
+#include <QStyle>
 
 #include <stdlib.h>
 #include <string.h>
 
 using namespace KCalendarCore;
 using namespace KAlarmCal;
-using namespace Akonadi;
 
 #if KDEPIM_HAVE_X11
 enum FullScreenType { NoFullScreen = 0, FullScreen = 1, FullScreenActive = 2 };
@@ -103,7 +103,7 @@ static FullScreenType findFullScreenWindows(const QVector<QRect>& screenRects, Q
 #include "kmailinterface.h"
 static const QLatin1String KMAIL_DBUS_SERVICE("org.kde.kmail");
 static const QLatin1String KMAIL_DBUS_PATH("/KMail");
- 
+
 // The delay for enabling message window buttons if a zero delay is
 // configured, i.e. the windows are placed far from the cursor.
 static const int proximityButtonDelay = 1000;    // (milliseconds)
@@ -170,52 +170,34 @@ MessageWin*           AudioThread::mAudioOwner = nullptr;
 * displayed.
 */
 MessageWin::MessageWin(const KAEvent* event, const KAAlarm& alarm, int flags)
-    : MainWindowBase(nullptr, static_cast<Qt::WindowFlags>(WFLAGS | WFLAGS2 | ((flags & ALWAYS_HIDE) || getWorkAreaAndModal() ? Qt::WindowType(0) : Qt::X11BypassWindowManagerHint))),
-      mMessage(event->cleanText()),
-      mFont(event->font()),
-      mBgColour(event->bgColour()),
-      mFgColour(event->fgColour()),
-      mEventItemId(event->itemId()),
-      mEventId(*event),
-      mAudioFile(event->audioFile()),
-      mVolume(event->soundVolume()),
-      mFadeVolume(event->fadeVolume()),
-      mFadeSeconds(qMin(event->fadeSeconds(), 86400)),
-      mDefaultDeferMinutes(event->deferDefaultMinutes()),
-      mAlarmType(alarm.type()),
-      mAction(event->actionSubType()),
-      mAkonadiItemId(event->akonadiItemId()),
-      mCommandError(event->commandError()),
-      mRestoreHeight(0),
-      mAudioRepeatPause(event->repeatSoundPause()),
-      mConfirmAck(event->confirmAck()),
-      mNoDefer(true),
-      mInvalid(false),
-      mEvent(*event),
-      mOriginalEvent(*event),
-      mCollection(AlarmCalendar::resources()->collectionForEvent(mEventItemId)),
-      mTimeLabel(nullptr),
-      mRemainingText(nullptr),
-      mEditButton(nullptr),
-      mDeferButton(nullptr),
-      mSilenceButton(nullptr),
-      mKMailButton(nullptr),
-      mCommandText(nullptr),
-      mDontShowAgainCheck(nullptr),
-      mEditDlg(nullptr),
-      mDeferDlg(nullptr),
-      mAlwaysHide(flags & ALWAYS_HIDE),
-      mErrorWindow(false),
-      mInitialised(false),
-      mNoPostAction(alarm.type() & KAAlarm::REMINDER_ALARM),
-      mRecreating(false),
-      mBeep(event->beep()),
-      mSpeak(event->speak()),
-      mRescheduleEvent(!(flags & NO_RESCHEDULE)),
-      mShown(false),
-      mPositioning(false),
-      mNoCloseConfirm(false),
-      mDisableDeferral(false)
+    : MainWindowBase(nullptr, static_cast<Qt::WindowFlags>(WFLAGS | WFLAGS2 | ((flags & ALWAYS_HIDE) || getWorkAreaAndModal() ? Qt::WindowType(0) : Qt::X11BypassWindowManagerHint)))
+    , mMessage(event->cleanText())
+    , mFont(event->font())
+    , mBgColour(event->bgColour())
+    , mFgColour(event->fgColour())
+    , mEventId(*event)
+    , mAudioFile(event->audioFile())
+    , mVolume(event->soundVolume())
+    , mFadeVolume(event->fadeVolume())
+    , mFadeSeconds(qMin(event->fadeSeconds(), 86400))
+    , mDefaultDeferMinutes(event->deferDefaultMinutes())
+    , mAlarmType(alarm.type())
+    , mAction(event->actionSubType())
+    , mAkonadiItemId(event->akonadiItemId())
+    , mCommandError(event->commandError())
+    , mRestoreHeight(0)
+    , mAudioRepeatPause(event->repeatSoundPause())
+    , mConfirmAck(event->confirmAck())
+    , mNoDefer(true)
+    , mInvalid(false)
+    , mEvent(*event)
+    , mOriginalEvent(*event)
+    , mResource(Resources::resourceForEvent(mEventId.eventId()))
+    , mAlwaysHide(flags & ALWAYS_HIDE)
+    , mNoPostAction(alarm.type() & KAAlarm::REMINDER_ALARM)
+    , mBeep(event->beep())
+    , mSpeak(event->speak())
+    , mRescheduleEvent(!(flags & NO_RESCHEDULE))
 {
     qCDebug(KALARM_LOG) << "MessageWin:" << (void*)this << "event" << mEventId;
     setAttribute(static_cast<Qt::WidgetAttribute>(WidgetFlags));
@@ -236,7 +218,7 @@ MessageWin::MessageWin(const KAEvent* event, const KAAlarm& alarm, int flags)
         mDateTime = alarm.dateTime(true);
     if (!(flags & (NO_INIT_VIEW | ALWAYS_HIDE)))
     {
-        const bool readonly = AlarmCalendar::resources()->eventReadOnly(mEventItemId);
+        const bool readonly = AlarmCalendar::resources()->eventReadOnly(mEventId.eventId());
         mShowEdit = !mEventId.isEmpty()  &&  !readonly;
         mNoDefer  = readonly || (flags & NO_DEFER) || alarm.repeatAtLogin();
         initView();
@@ -285,44 +267,25 @@ void MessageWin::showError(const KAEvent& event, const DateTime& alarmDateTime,
 */
 MessageWin::MessageWin(const KAEvent* event, const DateTime& alarmDateTime,
                        const QStringList& errmsgs, const QString& dontShowAgain)
-    : MainWindowBase(nullptr, WFLAGS | WFLAGS2),
-      mMessage(event->cleanText()),
-      mDateTime(alarmDateTime),
-      mEventItemId(event->itemId()),
-      mEventId(*event),
-      mAlarmType(KAAlarm::MAIN_ALARM),
-      mAction(event->actionSubType()),
-      mAkonadiItemId(-1),
-      mCommandError(KAEvent::CMD_NO_ERROR),
-      mErrorMsgs(errmsgs),
-      mDontShowAgain(dontShowAgain),
-      mRestoreHeight(0),
-      mConfirmAck(false),
-      mShowEdit(false),
-      mNoDefer(true),
-      mInvalid(false),
-      mEvent(*event),
-      mOriginalEvent(*event),
-      mTimeLabel(nullptr),
-      mRemainingText(nullptr),
-      mEditButton(nullptr),
-      mDeferButton(nullptr),
-      mSilenceButton(nullptr),
-      mKMailButton(nullptr),
-      mCommandText(nullptr),
-      mDontShowAgainCheck(nullptr),
-      mEditDlg(nullptr),
-      mDeferDlg(nullptr),
-      mAlwaysHide(false),
-      mErrorWindow(true),
-      mInitialised(false),
-      mNoPostAction(true),
-      mRecreating(false),
-      mRescheduleEvent(false),
-      mShown(false),
-      mPositioning(false),
-      mNoCloseConfirm(false),
-      mDisableDeferral(false)
+    : MainWindowBase(nullptr, WFLAGS | WFLAGS2)
+    , mMessage(event->cleanText())
+    , mDateTime(alarmDateTime)
+    , mEventId(*event)
+    , mAlarmType(KAAlarm::MAIN_ALARM)
+    , mAction(event->actionSubType())
+    , mAkonadiItemId(-1)
+    , mCommandError(KAEvent::CMD_NO_ERROR)
+    , mErrorMsgs(errmsgs)
+    , mDontShowAgain(dontShowAgain)
+    , mRestoreHeight(0)
+    , mConfirmAck(false)
+    , mShowEdit(false)
+    , mNoDefer(true)
+    , mInvalid(false)
+    , mEvent(*event)
+    , mOriginalEvent(*event)
+    , mErrorWindow(true)
+    , mNoPostAction(true)
 {
     qCDebug(KALARM_LOG) << "MessageWin: errmsg";
     setAttribute(static_cast<Qt::WidgetAttribute>(WidgetFlags));
@@ -338,26 +301,7 @@ MessageWin::MessageWin(const KAEvent* event, const DateTime& alarmDateTime,
 * The window is initialised by readProperties().
 */
 MessageWin::MessageWin()
-    : MainWindowBase(nullptr, WFLAGS),
-      mTimeLabel(nullptr),
-      mRemainingText(nullptr),
-      mEditButton(nullptr),
-      mDeferButton(nullptr),
-      mSilenceButton(nullptr),
-      mKMailButton(nullptr),
-      mCommandText(nullptr),
-      mDontShowAgainCheck(nullptr),
-      mEditDlg(nullptr),
-      mDeferDlg(nullptr),
-      mAlwaysHide(false),
-      mErrorWindow(false),
-      mInitialised(false),
-      mRecreating(false),
-      mRescheduleEvent(false),
-      mShown(false),
-      mPositioning(false),
-      mNoCloseConfirm(false),
-      mDisableDeferral(false)
+    : MainWindowBase(nullptr, WFLAGS)
 {
     qCDebug(KALARM_LOG) << "MessageWin:" << (void*)this << "restore";
     setAttribute(WidgetFlags);
@@ -705,10 +649,11 @@ void MessageWin::initView()
     else
         setDeferralLimit(mEvent);    // ensure that button is disabled when alarm can't be deferred any more
 
+    KIconLoader iconLoader;
     if (!mAudioFile.isEmpty()  &&  (mVolume || mFadeVolume > 0))
     {
         // Silence button to stop sound repetition
-        const QPixmap pixmap = MainBarIcon(QStringLiteral("media-playback-stop"));
+        const QPixmap pixmap = iconLoader.loadIcon(QStringLiteral("media-playback-stop"), KIconLoader::MainToolbar);
         mSilenceButton = new PushButton(topWidget);
         mSilenceButton->setIcon(pixmap);
         grid->addWidget(mSilenceButton, 0, gridIndex++, Qt::AlignHCenter);
@@ -718,7 +663,6 @@ void MessageWin::initView()
         mSilenceButton->setEnabled(false);
     }
 
-    KIconLoader iconLoader;
     if (mAkonadiItemId >= 0)
     {
         // KMail button
@@ -766,7 +710,7 @@ void MessageWin::initView()
     setMinimumSize(QSize(grid->sizeHint().width() + 2 * style()->pixelMetric(QStyle::PM_DefaultChildMargin),
                          sizeHint().height()));
     const bool modal = !(windowFlags() & Qt::X11BypassWindowManagerHint);
-    NET::States wstate = NET::Sticky | NET::StaysOnTop;
+    NET::States wstate = NET::Sticky | NET::KeepAbove;
     if (modal)
         wstate |= NET::Modal;
     WId winid = winId();
@@ -962,7 +906,7 @@ void MessageWin::saveProperties(KConfigGroup& config)
     if (mShown  &&  !mErrorWindow  &&  !mAlwaysHide)
     {
         config.writeEntry("EventID", mEventId.eventId());
-        config.writeEntry("EventItemID", mEventItemId);
+        config.writeEntry("CollectionID", mResource.id());
         config.writeEntry("AlarmType", static_cast<int>(mAlarmType));
         if (mAlarmType == KAAlarm::INVALID_ALARM)
             qCCritical(KALARM_LOG) << "MessageWin::saveProperties: Invalid alarm: id=" << mEventId << ", alarm count=" << mEvent.alarmCount();
@@ -1018,8 +962,8 @@ void MessageWin::saveProperties(KConfigGroup& config)
 void MessageWin::readProperties(const KConfigGroup& config)
 {
     mInvalid             = config.readEntry("Invalid", false);
-    QString eventId      = config.readEntry("EventID");
-    mEventItemId         = config.readEntry("EventItemID", Akonadi::Item::Id(-1));
+    const QString eventId         = config.readEntry("EventID");
+    const ResourceId collectionId = config.readEntry("CollectionID", ResourceId(-1));
     mAlarmType           = static_cast<KAAlarm::Type>(config.readEntry("AlarmType", 0));
     if (mAlarmType == KAAlarm::INVALID_ALARM)
     {
@@ -1064,9 +1008,9 @@ void MessageWin::readProperties(const KConfigGroup& config)
     mCommandError        = KAEvent::CmdErrType(config.readEntry("CmdErr", static_cast<int>(KAEvent::CMD_NO_ERROR)));
     mDontShowAgain       = config.readEntry("DontShowAgain", QString());
     mShowEdit            = false;
-    // Temporarily initialise mCollection and mEventId - they will be set by redisplayAlarm()
-    mCollection          = Akonadi::Collection();
-    mEventId             = EventId(mCollection.id(), eventId);
+    // Temporarily initialise mResource and mEventId - they will be set by redisplayAlarm()
+    mResource            = Resources::resource(collectionId);
+    mEventId             = EventId(collectionId, eventId);
     qCDebug(KALARM_LOG) << "MessageWin::readProperties:" << eventId;
     if (mAlarmType != KAAlarm::INVALID_ALARM)
     {
@@ -1076,10 +1020,10 @@ void MessageWin::readProperties(const KConfigGroup& config)
         else
         {
             // Close any other window for this alarm which has already been restored by redisplayAlarms()
-            if (!AkonadiModel::instance()->isCollectionTreeFetched())
+            if (!Resources::allCreated())
             {
-                connect(AkonadiModel::instance(), &Akonadi::EntityTreeModel::collectionTreeFetched,
-                                                  this, &MessageWin::showRestoredAlarm);
+                connect(Resources::instance(), &Resources::resourcesCreated,
+                                         this, &MessageWin::showRestoredAlarm);
                 return;
             }
             redisplayAlarm();
@@ -1102,8 +1046,8 @@ void MessageWin::showRestoredAlarm()
 */
 void MessageWin::redisplayAlarm()
 {
-    mCollection = AkonadiModel::instance()->collectionForItem(mEventItemId);
-    mEventId.setCollectionId(mCollection.id());
+    mResource = Resources::resourceForEvent(mEventId.eventId());
+    mEventId.setCollectionId(mResource.id());
     qCDebug(KALARM_LOG) << "MessageWin::redisplayAlarm:" << mEventId;
     // Delete any already existing window for the same event
     MessageWin* duplicate = findEvent(mEventId, this);
@@ -1120,7 +1064,7 @@ void MessageWin::redisplayAlarm()
     else
     {
         // It's not in the active calendar, so try the displaying or archive calendars
-        retrieveEvent(mEvent, mCollection, mShowEdit, mNoDefer);
+        retrieveEvent(mEvent, mResource, mShowEdit, mNoDefer);
         mNoDefer = !mNoDefer;
     }
     initView();
@@ -1142,15 +1086,12 @@ void MessageWin::redisplayAlarms()
     if (cal  &&  cal->isOpen())
     {
         KAEvent event;
-        Akonadi::Collection collection;
+        Resource resource;
         const Event::List events = cal->kcalEvents();
         for (int i = 0, end = events.count();  i < end;  ++i)
         {
             bool showDefer, showEdit;
-            reinstateFromDisplaying(events[i], event, collection, showEdit, showDefer);
-            Akonadi::Item::Id id = AkonadiModel::instance()->findItemId(event);
-            if (id >= 0)
-                event.setItemId(id);
+            reinstateFromDisplaying(events[i], event, resource, showEdit, showDefer);
             const EventId eventId(event);
             if (findEvent(eventId))
                 qCDebug(KALARM_LOG) << "MessageWin::redisplayAlarms: Message window already exists:" << eventId;
@@ -1167,8 +1108,8 @@ void MessageWin::redisplayAlarms()
                 const bool login = alarm.repeatAtLogin();
                 const int flags = NO_RESCHEDULE | (login ? NO_DEFER : 0) | NO_INIT_VIEW;
                 MessageWin* win = new MessageWin(&event, alarm, flags);
-                win->mCollection = collection;
-                const bool rw = CollectionControlModel::isWritableEnabled(collection, event.category()) > 0;
+                win->mResource = resource;
+                const bool rw = resource.isWritable(event.category());
                 win->mShowEdit = rw ? showEdit : false;
                 win->mNoDefer  = (rw && !login) ? !showDefer : true;
                 win->initView();
@@ -1182,7 +1123,7 @@ void MessageWin::redisplayAlarms()
 * Retrieves the event with the current ID from the displaying calendar file,
 * or if not found there, from the archive calendar.
 */
-bool MessageWin::retrieveEvent(KAEvent& event, Akonadi::Collection& resource, bool& showEdit, bool& showDefer)
+bool MessageWin::retrieveEvent(KAEvent& event, Resource& resource, bool& showEdit, bool& showDefer)
 {
     const Event::Ptr kcalEvent = AlarmCalendar::displayCalendar()->kcalEvent(CalEvent::uid(mEventId.eventId(), CalEvent::DISPLAYING));
     if (!reinstateFromDisplaying(kcalEvent, event, resource, showEdit, showDefer))
@@ -1190,9 +1131,9 @@ bool MessageWin::retrieveEvent(KAEvent& event, Akonadi::Collection& resource, bo
         // The event isn't in the displaying calendar.
         // Try to retrieve it from the archive calendar.
         KAEvent* ev = nullptr;
-        Akonadi::Collection archiveCol = CollectionControlModel::getStandard(CalEvent::ARCHIVED);
-        if (archiveCol.isValid())
-            ev = AlarmCalendar::resources()->event(EventId(archiveCol.id(), CalEvent::uid(mEventId.eventId(), CalEvent::ARCHIVED)));
+        Resource archiveRes = Resources::getStandard(CalEvent::ARCHIVED);
+        if (archiveRes.isValid())
+            ev = AlarmCalendar::resources()->event(EventId(archiveRes.id(), CalEvent::uid(mEventId.eventId(), CalEvent::ARCHIVED)));
         if (!ev)
             return false;
         event = *ev;
@@ -1201,7 +1142,7 @@ bool MessageWin::retrieveEvent(KAEvent& event, Akonadi::Collection& resource, bo
         if (mEventId.eventId() != event.id())
             qCCritical(KALARM_LOG) << "MessageWin::retrieveEvent: Wrong event ID";
         event.setEventId(mEventId.eventId());
-        resource  = Akonadi::Collection();
+        resource  = Resource();
         showEdit  = true;
         showDefer = true;
         qCDebug(KALARM_LOG) << "MessageWin::retrieveEvent:" << event.id() << ": success";
@@ -1213,14 +1154,14 @@ bool MessageWin::retrieveEvent(KAEvent& event, Akonadi::Collection& resource, bo
 * Retrieves the displayed event from the calendar file, or if not found there,
 * from the displaying calendar.
 */
-bool MessageWin::reinstateFromDisplaying(const Event::Ptr& kcalEvent, KAEvent& event, Akonadi::Collection& collection, bool& showEdit, bool& showDefer)
+bool MessageWin::reinstateFromDisplaying(const Event::Ptr& kcalEvent, KAEvent& event, Resource& resource, bool& showEdit, bool& showDefer)
 {
     if (!kcalEvent)
         return false;
     Akonadi::Collection::Id collectionId;
     event.reinstateFromDisplaying(kcalEvent, collectionId, showEdit, showDefer);
     event.setCollectionId(collectionId);
-    collection = AkonadiModel::instance()->collectionById(collectionId);
+    resource = Resources::resource(collectionId);
     qCDebug(KALARM_LOG) << "MessageWin::reinstateFromDisplaying:" << EventId(event) << ": success";
     return true;
 }
@@ -1243,8 +1184,8 @@ void MessageWin::alarmShowing(KAEvent& event)
     {
         // Copy the alarm to the displaying calendar in case of a crash, etc.
         KAEvent dispEvent;
-        const Akonadi::Collection collection = AkonadiModel::instance()->collectionForItem(event.itemId());
-        dispEvent.setDisplaying(event, mAlarmType, collection.id(),
+        const ResourceId id = Resources::resourceForEvent(event.id()).id();
+        dispEvent.setDisplaying(event, mAlarmType, id,
                                 mDateTime.effectiveKDateTime(), mShowEdit, !mNoDefer);
         AlarmCalendar* cal = AlarmCalendar::displayCalendarOpen();
         if (cal)
@@ -2027,17 +1968,17 @@ void MessageWin::slotShowKMailMessage()
         failed1 = false;
 
     // Select the mail folder containing the message
-    ItemFetchJob* job = new ItemFetchJob(Item(mAkonadiItemId));
-    job->fetchScope().setAncestorRetrieval(ItemFetchScope::Parent);
-    Item::List items;
+    Akonadi::ItemFetchJob* job = new Akonadi::ItemFetchJob(Akonadi::Item(mAkonadiItemId));
+    job->fetchScope().setAncestorRetrieval(Akonadi::ItemFetchScope::Parent);
+    Akonadi::Item::List items;
     if (job->exec())
         items = job->items();
     if (items.isEmpty()  ||  !items.at(0).isValid())
         qCWarning(KALARM_LOG) << "MessageWin::slotShowKMailMessage: No parent found for item" << mAkonadiItemId;
     else
     {
-        const Item& it = items.at(0);
-        const Collection::Id colId = it.parentCollection().id();
+        const Akonadi::Item& it = items.at(0);
+        const Akonadi::Collection::Id colId = it.parentCollection().id();
         reply = kmail.selectFolder(QString::number(colId));
         if (!reply.isValid())
             qCCritical(KALARM_LOG) << "kmail 'selectFolder' D-Bus call failed:" << reply.error().message();
@@ -2064,7 +2005,12 @@ void MessageWin::slotEdit()
     qCDebug(KALARM_LOG) << "MessageWin::slotEdit";
     MainWindow* mainWin = MainWindow::mainMainWindow();
     mEditDlg = EditAlarmDlg::create(false, &mOriginalEvent, false, mainWin, EditAlarmDlg::RES_IGNORE);
+#if KWINDOWSYSTEM_VERSION >= QT_VERSION_CHECK(5,62,0)
+    mEditDlg->setAttribute(Qt::WA_NativeWindow, true);
+    KWindowSystem::setMainWindow(mEditDlg->windowHandle(), winId());
+#else
     KWindowSystem::setMainWindow(mEditDlg, winId());
+#endif
     KWindowSystem::setOnAllDesktops(mEditDlg->winId(), false);
     setButtonsReadOnly(true);
     connect(mEditDlg, &QDialog::accepted, this, &MessageWin::editCloseOk);
@@ -2196,10 +2142,10 @@ void MessageWin::slotDefer()
         else
         {
             // Try to retrieve the event from the displaying or archive calendars
-            Akonadi::Collection collection;
+            Resource resource;
             KAEvent event;
             bool showEdit, showDefer;
-            if (!retrieveEvent(event, collection, showEdit, showDefer))
+            if (!retrieveEvent(event, resource, showEdit, showDefer))
             {
                 // The event doesn't exist any more !?!, so recurrence data,
                 // flags, and more, have been lost.
@@ -2217,7 +2163,7 @@ void MessageWin::slotDefer()
             event.setCommandError(mCommandError);
             // Add the event back into the calendar file, retaining its ID
             // and not updating KOrganizer.
-            KAlarm::addEvent(event, &collection, mDeferDlg, KAlarm::USE_EVENT_ID);
+            KAlarm::addEvent(event, &resource, mDeferDlg, KAlarm::USE_EVENT_ID);
             if (event.deferred())
                 mNoPostAction = true;
             // Finally delete it from the archived calendar now that it has
@@ -2246,7 +2192,7 @@ void MessageWin::slotDefer()
 */
 void MessageWin::displayMainWindow()
 {
-    KAlarm::displayMainWindowSelected(mEventItemId);
+    KAlarm::displayMainWindowSelected(mEventId.eventId());
 }
 
 /******************************************************************************
