@@ -1,7 +1,7 @@
 /*
  *  newalarmaction.cpp  -  menu action to select a new alarm type
  *  Program:  kalarm
- *  Copyright © 2007-2009,2011,2018 by David Jarvie <djarvie@kde.org>
+ *  Copyright © 2007-2019 David Jarvie <djarvie@kde.org>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -18,15 +18,16 @@
  *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
-#include "kalarm.h"
 #include "newalarmaction.h"
 
 #include "akonadimodel.h"
 #include "collectionmodel.h"
-#include "itemlistmodel.h"
 #include "functions.h"
 #include "shellprocess.h"
 #include "templatemenuaction.h"
+#include "resources/resources.h"
+#include "resources/eventmodel.h"
+#include "kalarm_debug.h"
 
 #include <KActionMenu>
 #include <KActionCollection>
@@ -35,7 +36,6 @@
 #include <KStandardShortcut>
 
 #include <QMenu>
-#include "kalarm_debug.h"
 
 using namespace KAlarmCal;
 
@@ -55,9 +55,8 @@ using namespace KAlarmCal;
 * the KActionCollection.
 */
 NewAlarmAction::NewAlarmAction(bool templates, const QString& label, QObject* parent, KActionCollection* collection)
-    : KActionMenu(QIcon::fromTheme(QStringLiteral("document-new")), label, parent),
-      mTemplateAction(nullptr),
-      mActionCollection(collection)
+    : KActionMenu(QIcon::fromTheme(QStringLiteral("document-new")), label, parent)
+    , mActionCollection(collection)
 {
     mDisplayAction = new QAction(QIcon::fromTheme(DISP_ICON), (templates ? i18nc("@item:inmenu", "&Display Alarm Template") : i18nc("@action", "New Display Alarm")), parent);
     menu()->addAction(mDisplayAction);
@@ -84,8 +83,8 @@ NewAlarmAction::NewAlarmAction(bool templates, const QString& label, QObject* pa
         // Include New From Template only in non-template menu
         mTemplateAction = new TemplateMenuAction(QIcon::fromTheme(TEMPLATE_ICON), i18nc("@action", "New Alarm From &Template"), parent);
         menu()->addAction(mTemplateAction);
-        connect(AkonadiModel::instance(), &AkonadiModel::collectionStatusChanged, this, &NewAlarmAction::slotCalendarStatusChanged);
-        connect(TemplateListModel::all(), &ItemListModel::haveEventsStatus, this, &NewAlarmAction::slotCalendarStatusChanged);
+        connect(Resources::instance(), &Resources::settingsChanged, this, &NewAlarmAction::slotCalendarStatusChanged);
+        connect(TemplateListModel::all<AkonadiModel>(), &EventListModel::haveEventsStatus, this, &NewAlarmAction::slotCalendarStatusChanged);
         slotCalendarStatusChanged();   // initialise action states
     }
     setDelayed(false);
@@ -172,8 +171,8 @@ void NewAlarmAction::slotSelected(QAction* action)
 void NewAlarmAction::slotCalendarStatusChanged()
 {
     // Find whether there are any writable active alarm calendars
-    bool active = !CollectionControlModel::enabledCollections(CalEvent::ACTIVE, true).isEmpty();
-    bool haveEvents = TemplateListModel::all()->haveEvents();
+    bool active = !Resources::enabledResources(CalEvent::ACTIVE, true).isEmpty();
+    bool haveEvents = TemplateListModel::all<AkonadiModel>()->haveEvents();
     mTemplateAction->setEnabled(active && haveEvents);
     setEnabled(active);
 }
