@@ -24,21 +24,18 @@
 
 #include "resourceselector.h"
 
-#include "kalarm.h"
 #include "alarmcalendar.h"
 #include "autoqpointer.h"
 #include "akonadiresourcecreator.h"
 #include "calendarmigrator.h"
+#include "collectionmodel.h"
 #include "kalarmapp.h"
 #include "messagebox.h"
 #include "packedlayout.h"
 #include "preferences.h"
-#include <AkonadiCore/agentmanager.h>
-#include <AkonadiCore/agentinstancecreatejob.h>
-#include <AkonadiCore/agenttype.h>
-#include <AkonadiCore/entitydisplayattribute.h>
-#include <AkonadiWidgets/collectionpropertiesdialog.h>
-#include <AkonadiWidgets/AgentConfigurationDialog>
+#include "resources/resources.h"
+#include "resources/resourcemodel.h"
+#include "kalarm_debug.h"
 
 #include <KLocalizedString>
 #include <kactioncollection.h>
@@ -53,25 +50,12 @@
 #include <QColorDialog>
 #include <QComboBox>
 #include <QMenu>
-#include "kalarm_debug.h"
 
 using namespace KCalendarCore;
-using namespace Akonadi;
 
 
 ResourceSelector::ResourceSelector(QWidget* parent)
-    : QFrame(parent),
-      mContextMenu(nullptr),
-      mActionReload(nullptr),
-      mActionShowDetails(nullptr),
-      mActionSetColour(nullptr),
-      mActionClearColour(nullptr),
-      mActionEdit(nullptr),
-      mActionUpdate(nullptr),
-      mActionRemove(nullptr),
-      mActionImport(nullptr),
-      mActionExport(nullptr),
-      mActionSetDefault(nullptr)
+    : QFrame(parent)
 {
     QBoxLayout* topLayout = new QVBoxLayout(this);
 
@@ -87,11 +71,11 @@ ResourceSelector::ResourceSelector(QWidget* parent)
     topLayout->addWidget(mAlarmType);
     // No spacing between combo box and listview.
 
-    CollectionFilterCheckListModel* model = new CollectionFilterCheckListModel(this);
-    mListView = new CollectionView(model, this);
+    ResourceFilterCheckListModel* model = ResourceFilterCheckListModel::create<AkonadiModel>(this);
+    mListView = new ResourceView(model, this);
     connect(mListView->selectionModel(), &QItemSelectionModel::selectionChanged, this, &ResourceSelector::selectionChanged);
     mListView->setContextMenuPolicy(Qt::CustomContextMenu);
-    connect(mListView, &CollectionView::customContextMenuRequested, this, &ResourceSelector::contextMenuRequested);
+    connect(mListView, &ResourceView::customContextMenuRequested, this, &ResourceSelector::contextMenuRequested);
     mListView->setWhatsThis(i18nc("@info:whatsthis",
                                   "List of available calendars of the selected type. The checked state shows whether a calendar "
                                  "is enabled (checked) or disabled (unchecked). The default calendar is shown in bold."));
@@ -116,10 +100,8 @@ ResourceSelector::ResourceSelector(QWidget* parent)
     connect(mEditButton, &QPushButton::clicked, this, &ResourceSelector::editResource);
     connect(mDeleteButton, &QPushButton::clicked, this, &ResourceSelector::removeResource);
 
-    connect(AkonadiModel::instance(), &AkonadiModel::collectionAdded,
-                                this, &ResourceSelector::slotCollectionAdded);
-    connect(AkonadiModel::instance(), &AkonadiModel::collectionDeleted,
-                                this, &ResourceSelector::selectionChanged);
+    connect(Resources::instance(), &Resources::resourceRemoved,
+                             this, &ResourceSelector::selectionChanged);
 
     connect(mAlarmType, static_cast<void (QComboBox::*)(int)>(&QComboBox::activated), this, &ResourceSelector::alarmTypeSelected);
     QTimer::singleShot(0, this, SLOT(alarmTypeSelected()));
@@ -154,7 +136,7 @@ void ResourceSelector::alarmTypeSelected()
     // in reinstateAlarmTypeScrollBars() description).
     mListView->setVerticalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
     mListView->setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
-    mListView->collectionModel()->setEventTypeFilter(mCurrentAlarmType);
+    mListView->resourceModel()->setEventTypeFilter(mCurrentAlarmType);
     mAddButton->setWhatsThis(addTip);
     mAddButton->setToolTip(addTip);
     // WORKAROUND: Switch scroll bars back on after allowing geometry to update ...
@@ -188,64 +170,34 @@ void ResourceSelector::reinstateAlarmTypeScrollBars()
 void ResourceSelector::addResource()
 {
     AkonadiResourceCreator* creator = new AkonadiResourceCreator(mCurrentAlarmType, this);
-    connect(creator, &AkonadiResourceCreator::finished, this, &ResourceSelector::resourceAdded);
+    connect(creator, &AkonadiResourceCreator::resourceAdded, this, &ResourceSelector::slotResourceAdded);
     creator->createResource();
 }
 
 /******************************************************************************
-* Called when the job started by AkonadiModel::addCollection() has completed.
+* Called when a collection is added to the AkonadiModel, after being created
+* by addResource().
 */
-void ResourceSelector::resourceAdded(AkonadiResourceCreator* creator, bool success)
+void ResourceSelector::slotResourceAdded(Resource& resource, CalEvent::Type alarmType)
 {
-    if (success)
+    const CalEvent::Types types = resource.alarmTypes();
+    resource.setEnabled(types);
+    if (!(types & alarmType))
     {
-        AgentInstance agent = creator->agentInstance();
-        qCDebug(KALARM_LOG) << "ResourceSelector::resourceAdded:" << agent.isValid();
-        if (agent.isValid())
+        // The user has selected alarm types for the resource
+        // which don't include the currently displayed type.
+        // Show a collection list which includes a selected type.
+        int index = -1;
+        if (types & CalEvent::ACTIVE)
+            index = 0;
+        else if (types & CalEvent::ARCHIVED)
+            index = 1;
+        else if (types & CalEvent::TEMPLATE)
+            index = 2;
+        if (index >= 0)
         {
-            // Note that we're expecting the agent's Collection to be added
-            mAddAgents += agent;
-        }
-    }
-    delete creator;
-}
-
-/******************************************************************************
-* Called when a collection is added to the AkonadiModel.
-*/
-void ResourceSelector::slotCollectionAdded(const Collection& collection)
-{
-    if (collection.isValid())
-    {
-        AgentInstance agent = AgentManager::self()->instance(collection.resource());
-        if (agent.isValid())
-        {
-            int i = mAddAgents.indexOf(agent);
-            if (i >= 0)
-            {
-                // The collection belongs to an agent created by addResource()
-                const CalEvent::Types types = CalEvent::types(collection.contentMimeTypes());
-                CollectionControlModel::setEnabled(collection, types, true);
-                if (!(types & mCurrentAlarmType))
-                {
-                    // The user has selected alarm types for the resource
-                    // which don't include the currently displayed type.
-                    // Show a collection list which includes a selected type.
-                    int index = -1;
-                    if (types & CalEvent::ACTIVE)
-                        index = 0;
-                    else if (types & CalEvent::ARCHIVED)
-                        index = 1;
-                    else if (types & CalEvent::TEMPLATE)
-                        index = 2;
-                    if (index >= 0)
-                    {
-                        mAlarmType->setCurrentIndex(index);
-                        alarmTypeSelected();
-                    }
-                }
-                mAddAgents.removeAt(i);
-            }
+            mAlarmType->setCurrentIndex(index);
+            alarmTypeSelected();
         }
     }
 }
@@ -255,17 +207,7 @@ void ResourceSelector::slotCollectionAdded(const Collection& collection)
 */
 void ResourceSelector::editResource()
 {
-    const Collection collection = currentResource();
-    if (collection.isValid())
-    {
-        AgentInstance instance = AgentManager::self()->instance(collection.resource());
-        if (instance.isValid())
-        {
-            QPointer<AgentConfigurationDialog> dlg = new AgentConfigurationDialog(instance, this);
-            dlg->exec();
-            delete dlg;
-        }
-    }
+    currentResource().editResource(this);
 }
 
 /******************************************************************************
@@ -274,11 +216,10 @@ void ResourceSelector::editResource()
 */
 void ResourceSelector::updateResource()
 {
-    Collection collection = currentResource();
-    if (!collection.isValid())
+    const Resource resource = currentResource();
+    if (!resource.isValid())
         return;
-    AkonadiModel::instance()->refresh(collection);  // update with latest data
-    CalendarMigrator::updateToCurrentFormat(collection, true, this);
+    CalendarMigrator::updateToCurrentFormat(resource, true, this);
 }
 
 /******************************************************************************
@@ -286,13 +227,13 @@ void ResourceSelector::updateResource()
 */
 void ResourceSelector::removeResource()
 {
-    Collection collection = currentResource();
-    if (!collection.isValid())
+    Resource resource = currentResource();
+    if (!resource.isValid())
         return;
-    const QString name = collection.name();
+    const QString name = resource.configName();
     // Check if it's the standard or only resource for at least one type.
-    const CalEvent::Types allTypes      = AkonadiModel::types(collection);
-    const CalEvent::Types standardTypes = CollectionControlModel::standardTypes(collection, true);
+    const CalEvent::Types allTypes      = resource.alarmTypes();
+    const CalEvent::Types standardTypes = Resources::standardTypes(resource, true);
     const CalEvent::Type  currentType   = currentResourceType();
     const CalEvent::Type  stdType = (standardTypes & CalEvent::ACTIVE)   ? CalEvent::ACTIVE
                                   : (standardTypes & CalEvent::ARCHIVED) ? CalEvent::ARCHIVED
@@ -317,11 +258,11 @@ void ResourceSelector::removeResource()
         if (allTypes != currentType)
         {
             // It also contains alarm types other than the currently displayed type
-            const QString stdTypes = CollectionControlModel::typeListForDisplay(standardTypes);
+            const QString stdTypes = CalendarDataModel::typeListForDisplay(standardTypes);
             QString otherTypes;
             const CalEvent::Types nonStandardTypes(allTypes & ~standardTypes);
             if (nonStandardTypes != currentType)
-                otherTypes = xi18nc("@info", "<para>It also contains:%1</para>", CollectionControlModel::typeListForDisplay(nonStandardTypes));
+                otherTypes = xi18nc("@info", "<para>It also contains:%1</para>", CalendarDataModel::typeListForDisplay(nonStandardTypes));
             text = xi18nc("@info", "<para><resource>%1</resource> is the default calendar for:%2</para>%3"
                                   "<para>Do you really want to remove it from all calendar lists?</para>", name, stdTypes, otherTypes);
         }
@@ -330,13 +271,13 @@ void ResourceSelector::removeResource()
     }
     else if (allTypes != currentType)
         text = xi18nc("@info", "<para><resource>%1</resource> contains:%2</para><para>Do you really want to remove it from all calendar lists?</para>",
-                     name, CollectionControlModel::typeListForDisplay(allTypes));
+                     name, CalendarDataModel::typeListForDisplay(allTypes));
     else
         text = xi18nc("@info", "Do you really want to remove the calendar <resource>%1</resource> from the list?", name);
     if (KAMessageBox::warningContinueCancel(this, text, QString(), KStandardGuiItem::remove()) == KMessageBox::Cancel)
         return;
 
-    AkonadiModel::instance()->removeCollection(collection);
+    CollectionControlModel::removeResource(resource);
 }
 
 /******************************************************************************
@@ -405,36 +346,35 @@ void ResourceSelector::contextMenuRequested(const QPoint& viewportPos)
     bool active    = false;
     bool writable  = false;
     bool updatable = false;
-    Collection collection;
+    Resource resource;
     if (mListView->selectionModel()->hasSelection())
     {
         const QModelIndex index = mListView->indexAt(viewportPos);
         if (index.isValid())
-            collection = mListView->collectionModel()->collection(index);
+            resource = mListView->resourceModel()->resource(index);
         else
             mListView->clearSelection();
     }
     CalEvent::Type type = currentResourceType();
-    bool haveCalendar = collection.isValid();
+    bool haveCalendar = resource.isValid();
     if (haveCalendar)
     {
-        // Note: the CollectionControlModel functions call AkonadiModel::refresh(collection)
-        active   = CollectionControlModel::isEnabled(collection, type);
-        KACalendar::Compat compatibility;
-        int rw = CollectionControlModel::isWritableEnabled(collection, type, compatibility);
+        active = resource.isEnabled(type);
+        const int rw = resource.writableStatus(type);
         writable = (rw > 0);
+        const KACalendar::Compat compatibility = resource.compatibility();
         if (!rw
         &&  (compatibility & ~KACalendar::Converted)
         &&  !(compatibility & ~(KACalendar::Convertible | KACalendar::Converted)))
             updatable = true; // the calendar format is convertible to the current KAlarm format
-        if (!(AkonadiModel::instance()->types(collection) & type))
+        if (!(resource.alarmTypes() & type))
             type = CalEvent::EMPTY;
     }
     mActionReload->setEnabled(active);
     mActionShowDetails->setEnabled(haveCalendar);
     mActionSetColour->setEnabled(haveCalendar);
     mActionClearColour->setEnabled(haveCalendar);
-    mActionClearColour->setVisible(AkonadiModel::instance()->backgroundColor(collection).isValid());
+    mActionClearColour->setVisible(resource.backgroundColour().isValid());
     mActionEdit->setEnabled(haveCalendar);
     mActionUpdate->setEnabled(updatable);
     mActionRemove->setEnabled(haveCalendar);
@@ -449,7 +389,7 @@ void ResourceSelector::contextMenuRequested(const QPoint& viewportPos)
         default:  break;
     }
     mActionSetDefault->setText(text);
-    bool standard = CollectionControlModel::isStandard(collection, type);
+    bool standard = Resources::isStandard(resource, type);
     mActionSetDefault->setChecked(active && writable && standard);
     mActionSetDefault->setEnabled(active && writable);
     mContextMenu->popup(mListView->viewport()->mapToGlobal(viewportPos));
@@ -460,9 +400,9 @@ void ResourceSelector::contextMenuRequested(const QPoint& viewportPos)
 */
 void ResourceSelector::reloadResource()
 {
-    const Collection collection = currentResource();
-    if (collection.isValid())
-        AkonadiModel::instance()->reloadCollection(collection);
+    const Resource resource = currentResource();
+    if (resource.isValid())
+        AkonadiModel::instance()->reloadResource(resource);
 }
 
 /******************************************************************************
@@ -482,9 +422,9 @@ void ResourceSelector::archiveDaysChanged(int days)
 {
     if (days)
     {
-        const Collection col = CollectionControlModel::getStandard(CalEvent::ARCHIVED);
-        if (col.isValid())
-            theApp()->purgeNewArchivedDefault(col);
+        const Resource resource = Resources::getStandard(CalEvent::ARCHIVED);
+        if (resource.isValid())
+            theApp()->purgeNewArchivedDefault(resource);
     }
 }
 
@@ -494,16 +434,16 @@ void ResourceSelector::archiveDaysChanged(int days)
 */
 void ResourceSelector::setStandard()
 {
-    Collection collection = currentResource();
-    if (collection.isValid())
+    Resource resource = currentResource();
+    if (resource.isValid())
     {
         CalEvent::Type alarmType = currentResourceType();
         bool standard = mActionSetDefault->isChecked();
         if (standard)
-            CollectionControlModel::setEnabled(collection, alarmType, true);
-        CollectionControlModel::setStandard(collection, alarmType, standard);
+            resource.setEnabled(alarmType, true);
+        Resources::setStandard(resource, alarmType, standard);
         if (alarmType == CalEvent::ARCHIVED)
-            theApp()->purgeNewArchivedDefault(collection);
+            theApp()->purgeNewArchivedDefault(resource);
     }
 }
 
@@ -514,8 +454,8 @@ void ResourceSelector::setStandard()
 */
 void ResourceSelector::importCalendar()
 {
-    Collection collection = currentResource();
-    AlarmCalendar::importAlarms(this, (collection.isValid() ? &collection : nullptr));
+    Resource resource = currentResource();
+    AlarmCalendar::resources()->importAlarms(this, &resource);
 }
 
 /******************************************************************************
@@ -524,9 +464,9 @@ void ResourceSelector::importCalendar()
 */
 void ResourceSelector::exportCalendar()
 {
-    const Collection calendar = currentResource();
-    if (calendar.isValid())
-        AlarmCalendar::exportAlarms(AlarmCalendar::resources()->events(calendar), this);
+    const Resource resource = currentResource();
+    if (resource.isValid())
+        AlarmCalendar::exportAlarms(AlarmCalendar::resources()->events(resource), this);
 }
 
 /******************************************************************************
@@ -534,15 +474,15 @@ void ResourceSelector::exportCalendar()
 */
 void ResourceSelector::setColour()
 {
-    Collection collection = currentResource();
-    if (collection.isValid())
+    Resource resource = currentResource();
+    if (resource.isValid())
     {
-        QColor colour = AkonadiModel::instance()->backgroundColor(collection);
+        QColor colour = resource.backgroundColour();
         if (!colour.isValid())
             colour = QApplication::palette().color(QPalette::Base);
         colour = QColorDialog::getColor(colour, this);
         if (colour.isValid())
-            AkonadiModel::instance()->setBackgroundColor(collection, colour);
+            resource.setBackgroundColour(colour);
     }
 }
 
@@ -552,9 +492,9 @@ void ResourceSelector::setColour()
 */
 void ResourceSelector::clearColour()
 {
-    Collection collection = currentResource();
-    if (collection.isValid())
-        AkonadiModel::instance()->setBackgroundColor(collection, QColor());
+    Resource resource = currentResource();
+    if (resource.isValid())
+        resource.setBackgroundColour(QColor());
 }
 
 /******************************************************************************
@@ -562,19 +502,16 @@ void ResourceSelector::clearColour()
 */
 void ResourceSelector::showInfo()
 {
-    Collection collection = currentResource();
-    if (collection.isValid())
+    const Resource resource = currentResource();
+    if (resource.isValid())
     {
-        const QString name = collection.displayName();
-        const QString id = collection.resource();   // resource name
+        const QString name             = resource.displayName();
+        const QString id               = resource.configName();   // resource name
+        const QString calType          = resource.storageTypeString(true);
         const CalEvent::Type alarmType = currentResourceType();
-        const QString calType = AgentManager::self()->instance(id).type().name();
-        const QString storage = AkonadiModel::instance()->storageType(collection);
-        QString location = collection.remoteId();
-        const QUrl url = QUrl::fromUserInput(location, QString(), QUrl::AssumeLocalFile);
-        if (url.isLocalFile())
-            location = url.path();
-        const CalEvent::Types altypes = AkonadiModel::instance()->types(collection);
+        const QString storage          = resource.storageTypeString(false);
+        const QString location         = resource.displayLocation();
+        const CalEvent::Types altypes  = resource.alarmTypes();
         QStringList alarmTypes;
         if (altypes & CalEvent::ACTIVE)
             alarmTypes << i18nc("@info", "Active alarms");
@@ -583,13 +520,13 @@ void ResourceSelector::showInfo()
         if (altypes & CalEvent::TEMPLATE)
             alarmTypes << i18nc("@info", "Alarm templates");
         const QString alarmTypeString = alarmTypes.join(i18nc("@info List separator", ", "));
-        QString perms = AkonadiModel::readOnlyTooltip(collection);
+        QString perms = AkonadiModel::readOnlyTooltip(resource);
         if (perms.isEmpty())
             perms = i18nc("@info", "Read-write");
-        const QString enabled = CollectionControlModel::isEnabled(collection, alarmType)
+        const QString enabled = resource.isEnabled(alarmType)
                            ? i18nc("@info", "Enabled")
                            : i18nc("@info", "Disabled");
-        const QString std = CollectionControlModel::isStandard(collection, alarmType)
+        const QString std = Resources::isStandard(resource, alarmType)
                            ? i18nc("@info Parameter in 'Default calendar: Yes/No'", "Yes")
                            : i18nc("@info Parameter in 'Default calendar: Yes/No'", "No");
         const QString text = xi18nc("@info",
@@ -602,7 +539,7 @@ void ResourceSelector::showInfo()
                                     "Status: %8<nl/>"
                                     "Default calendar: %9</para>",
                                     name, id, calType, alarmTypeString, storage, location, perms, enabled, std);
-        // Display the collection information. Because the user requested
+        // Display the resource information. Because the user requested
         // the information, don't raise a KNotify event.
         KAMessageBox::information(this, text, QString(), QString(), KMessageBox::Options());
     }
@@ -611,9 +548,9 @@ void ResourceSelector::showInfo()
 /******************************************************************************
 * Return the currently selected resource in the list.
 */
-Collection ResourceSelector::currentResource() const
+Resource ResourceSelector::currentResource() const
 {
-    return mListView->collection(mListView->selectionModel()->currentIndex());
+    return mListView->resource(mListView->selectionModel()->currentIndex());
 }
 
 /******************************************************************************
